package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.OmsFeign;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.*;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:10
 */
@RestController
@RequestMapping("${api.version}/oms")
public class OMSController {


    @Autowired
    OmsFeign omsFeign;
    
    //********************************************omsTruckOrderController*****************************

    @ApiOperation(value = "查询所有运输订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(86)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllTruckOrder")
    public Map<String, Object> getAllTruckOrder(@RequestBody(required = false) Map<String, Object> mapValue,
                                                Integer apiId,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer orderStatus,
                                                Integer planId,
                                                Integer orderType,
                                                Integer fuelOrder,
                                                String carrierSSOId,
                                                String con,
                                                String startTime,
                                                String endTime) {
        return omsFeign.getAllTruckOrder(mapValue == null? new HashMap<>() : mapValue, apiId, pageNum, pageSize,
                orderStatus, planId, orderType, fuelOrder,carrierSSOId, con,startTime,endTime);
    }

    @ApiOperation(value = "不适用表头返回数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/getAllTruckOrderReturnListMap")
    public Map<String, Object> getAllTruckOrderReturnListMap(Integer orderStatus, Integer planId, Integer orderType) {
        return omsFeign.getAllTruckOrderReturnListMap(orderStatus, planId, orderType);
    }

    @ApiOperation(value = "查询所有空闲的运力信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(85)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllCapacity")
    public Map<String, Object> getAllCapacity(@RequestBody(required = false) Map<String, Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        Integer carrierId
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return omsFeign.getAllCapacity(mapValue, apiId, pageNum, pageSize, carrierId);
    }

    @ApiOperation(value = "新增采购进口矿订单 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/addInputOrder")
    public Map<String,Object> addInputOrder(@RequestBody(required = false) Map<String, Object> mapValue) {
        return omsFeign.addInputOrder(mapValue);
    }

    @ApiOperation(value = "分解运输计划后 新增订单  或者直接新增订单 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/addPurOrder")
    public Map<String, Object> addPurOrder(@RequestBody(required = false) Map<String, Object> mapValue) {
        return omsFeign.addPurOrder(mapValue);
    }

    //采购内转派单
    @ApiOperation(value = "采购内转派单")
    @PostMapping("/addPurInwardOrder")
    public Map<String,Object> addPurInwardOrder(@RequestBody(required = false) Map<String,Object>mapValue) {
        return omsFeign.addPurInwardOrder(mapValue);
    }

    @ApiOperation(value = "修改分派计划")
    @PostMapping("/updateOrder")
    public Map<String, Object> updateOrder(@RequestBody Map<String, Object> map) {
        return omsFeign.updateOrder(map);
    }

    @ApiOperation(value = "派单")
    @PostMapping("/dispatchOrder")
    public Map<String, Object> dispatchOrder(@RequestBody(required = false) Map<String, Object> mapValue) {
        return omsFeign.dispatchOrder(mapValue);
    }

    @ApiOperation(value = "销售派单")
    @PostMapping("/dispatchOrderForSale")
    public Map<String, Object> dispatchorderForSale(@RequestBody(required = false) Map<String, Object> map) {
        return omsFeign.dispatchOrderForSale(map);
    }


    @ApiOperation(value = "逻辑删除运单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/deleteOrder")
    public Map<String, Object> deleteOrder(@RequestBody(required = false) Map<String, Object> map,
                                     Integer planId) {
        return omsFeign.deleteOrder(map, planId);
    }

    @ApiOperation(value = "司机接收、拒绝接单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/driverReceiveOrRefuse")
    public Map<String, Object> driverReceiveOrRefuse(@RequestBody(required = false) Map<String, Object> map) {
        return omsFeign.driverReceiveOrRefuse(map);
    }
    @ApiOperation(value="撤销订单")
    @PostMapping("/undoOrder")
    public Map<String, Object> undoOrder(@RequestBody Map<String,Object> map) {
        return omsFeign.undoOrder(map);
    }

    @ApiOperation(value = "撤销已拒绝")
    @PostMapping("/refuseCtrlZ")
    public Map<String,Object> refuseCtrlZ(@RequestBody Map<String,Object> map){
        return omsFeign.refuseCtrlZ(map);
    }



    @ApiOperation(value="司机接单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(117)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getReceiveRefuseOrder/{orderReceiveStatus}")
    public Map<String, Object> getReceiveRefuseOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               @PathVariable Integer orderReceiveStatus,
                                               Integer orderType,
                                               Integer orderStatus, String con
    ){
        return omsFeign.getReceiveRefuseOrder(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum,
                pageSize, orderReceiveStatus, orderType, orderStatus, con);
    }


    @ApiOperation(value="司机APP端调用接口查询数据 4 已下发 5 已接收")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "capacityNumber", value = "车牌号", required = false, dataType = "String"),
    })
    @PostMapping("/sendMesToDriver")
    public Map<String, Object> sendMesToDriver(String capacityNumber, Integer orderStatus){
        return omsFeign.sendMesToDriver(capacityNumber, orderStatus);
    }

    @ApiOperation(value="通过车牌获取所有已拒绝的订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "capacityNumber", value = "车牌号", required = false, dataType = "String"),
    })
    @PostMapping("/getRefuseOrderByCapacityNum")
    public Map<String, Object> sendMesToDriver(String capacityNumber){
        return omsFeign.sendMesToDriver(capacityNumber);
    }

    @ApiOperation(value="通过运输订单ID查询运单信息 包含各个作业路径")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/getOrderMesByOrderNum/{orderId}")
    public Map<String, Object> getOrderMesByOrderNum(@PathVariable("orderId") Integer orderId){
        return omsFeign.getOrderMesByOrderNum(orderId);
    }

    @ApiOperation(value="通过运输订单ID查询实绩地点和时间")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectPlaceAndTime/{orderId}")
    public Map<String, Object> selectPlaceAndTime(@PathVariable("orderId") Integer orderId){
        return omsFeign.selectPlaceAndTime(orderId);
    }

    @ApiOperation(value="通过运输订单ID查询运单信息")
    @PostMapping("/selectOrderByOrderId/{orderId}")
    public Map<String, Object> selectOrderByOrderId(@PathVariable("orderId") Integer orderId){
        return omsFeign.selectOrderByOrderId(orderId);
    }

    @ApiOperation(value="查看运输派单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(117)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getTransportDispatch")
    public Map<String, Object> getTransportDispatch(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer orderType,
                                              Integer orderStatus, Integer fuelOrder,String carrierSSOId,String con,
                                                    String startTime,
                                                    String endTime){
        return omsFeign.getTransportDispatch(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize,
                 orderType, orderStatus, fuelOrder,carrierSSOId,con,startTime,endTime);
    }

    /**
     * 展示承运商接收销售公司已接受的销售订单
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/getSaleOrderForCarrierList/{carrierId}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "168", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getSaleOrderForCarrierList(@RequestBody(required = false)Map<String,Object> map,
                                                          @PathVariable("carrierId") Integer carrierId,
                                                          Integer apiId,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          String con
                                                          ) {
        return omsFeign.getSaleOrderForCarrierList(map==null ? new HashMap<>():map,carrierId, apiId, pageNum, pageSize,con);

    }

    /**
     * 展示承运商接收销售公司已接受的销售订单
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/selectAllOrderForSale/{carrierId}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "168", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> selectAllOrderForSale( @RequestBody(required = false) Map<String,Object> mapValue,
                                                      @PathVariable Integer carrierId,
                                                      Integer apiId,
                                                      Integer pageNum,
                                                      Integer pageSize,
                                                      Integer orderType,
                                                      Integer orderStatus,
                                                      Integer saleOrderMaterialId,
                                                      String  con
                                                    ) {
        return omsFeign.selectAllOrderForSale(mapValue==null?new HashMap<>():mapValue, carrierId, apiId, pageNum, pageSize, orderType, orderStatus, saleOrderMaterialId, con);
    }
    /**
     * 展示承运商接收销售公司已接受的销售订单
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/getTransportOrder")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "168", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getTransportOrder( @RequestBody(required = false) Map<String, Object> mapValue,
                                                  Integer apiId,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                   Integer orderId,
                                                  Integer orderStatus
    ) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        return omsFeign.getTransportOrder(mapValue,apiId,pageNum,pageSize,orderId,orderStatus);
    }








    /**
     * 销售物流：司机接单pc端
     */

    @ApiOperation(value="pc端展示司机信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(226)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getDriverInfoForSale")
    public Map<String,Object> getDriverInfoForSale(@RequestBody(required = false) Map<String, Object> mapValue,
                                                   Integer apiId,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   Integer orderType,
                                                   Integer orderStatus,
                                                   String con,
                                                   String carrierSsoId,
                                                   Integer shipperId
    )
    {
        return omsFeign.getDriverInfoForSale(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,orderType,orderStatus, con,carrierSsoId,shipperId);
    }
    @PostMapping("/getDriverInfoForSale1")
    public Map<String,Object> getDriverInfoForSale1(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   Integer orderStatus,
                                                   String con,
                                                   String numberPlate,
                                                   @RequestParam Integer saleOrderId
    )
    {
        return omsFeign.getDriverInfoForSale1(mapValue==null?new HashMap<>():mapValue,orderStatus, con,numberPlate,saleOrderId);
    }



    /**
     * 查询所有已经接收的焦炭发运日计划
     *
     * @param carrierId
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @PostMapping("/getCokeDayPlanAndRecivedList/{carrierId}")

    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "169", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getCokeDayPlanAndRecivedList(
                                                            @RequestBody(required = false)Map<String,Object> map,
                                                            @PathVariable("carrierId") Integer carrierId,
                                                            @RequestParam Integer apiId,
                                                            @RequestParam Integer pageNum,
                                                            @RequestParam Integer pageSize) {
        return omsFeign.getCokeDayPlanAndRecivedList(map==null?new HashMap<>():map,carrierId, apiId, pageNum, pageSize);
    }

    /**
     * 查询所有已经接收的水渣发运日计划
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/getWaterSlagDayPlanAndRecivedList/{carrierId}")

    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "170", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getWaterSlagDayPlanAndRecivedList(
                                                                 @RequestBody(required = false)Map<String,Object> map,
                                                                 @PathVariable("carrierId") Integer carrierId,
                                                                 @RequestParam Integer apiId,
                                                                 @RequestParam Integer pageNum,
                                                                 @RequestParam Integer pageSize) {
        return omsFeign.getWaterSlagDayPlanAndRecivedList(map==null?new HashMap<>():map, carrierId, apiId, pageNum, pageSize);
    }
    @ApiOperation(value="通过物资ID和发货单位ID查找采购订单号")
    @PostMapping("/selectNewOrderId")
    public Map<String, Object> selectNewOrderId(@RequestBody(required=false) Map<String,Object> map){
        return omsFeign.selectNewOrderId(map);
    }
    @ApiOperation(value="查询所有空闲的司机排班信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(186)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getCapacityForLeisure/{carrierId}")
    public Map<String, Object> getCapacityForLeisure(@RequestBody(required = false) Map<String,Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     @PathVariable Integer carrierId) {
        return omsFeign.getCapacityForLeisure(mapValue==null?new HashMap<>(): mapValue, apiId, pageNum, pageSize,carrierId);
    }
     //获取已经形成订单的焦炭计划
    @PostMapping(value = "/getCokeRailDayPlanForGenOrder/{carrierId}")
    public Map<String,Object>  getCokeRailDayPlanForGenOrder(@RequestBody(required = false)Map<String,Object> map,
                                                           @PathVariable("carrierId") Integer carrierId,
                                                           Integer pageNum,
                                                           Integer pageSize,
                                                           Integer apiId,
                                                           Integer dayPlanId,
                                                           Integer orderStatus,
                                                           Integer orderType,
                                                           String con
    ){
        return  omsFeign.getCokeRailDayPlanForGenOrder(map==null?new HashMap<>():map, carrierId, pageNum, pageSize, apiId, dayPlanId, orderStatus, orderType, con);
    }


   //获取已经形成订单的水渣计划
   @PostMapping(value = "/getWaterslagDayPlanForGenOrder/{carrierId}")
   public Map<String, Object>     getWaterslagDayPlanForGenOrder(@RequestBody(required = false)Map<String,Object> map,
                                                                 @PathVariable("carrierId") Integer carrierId,
                                                                 Integer pageNum,
                                                                 Integer pageSize,
                                                                 Integer apiId,
                                                                 Integer dayPlanId,
                                                                 Integer orderStatus,
                                                                 Integer orderType,
                                                                 String con


   ){
        return omsFeign.getWaterslagDayPlanForGenOrder(map==null?new HashMap<>():map, carrierId, pageNum, pageSize, apiId, dayPlanId, orderStatus,orderType, con);

   }

    @ApiOperation(value="车牌号下拉")
    @GetMapping("/getDriverCapacity")
    public Map<String, Object> getDriverCapacity() {
        Map<String,Object> map = omsFeign.getDriverCapacity();
        return map;
    }

    @ApiOperation(value="派单信息")
    @PostMapping("/getTruckNoDispatchMap")
    public Map<String, Object> getTruckNoDispatchMap(Integer dispatchId) {
        Map<String,Object> map = omsFeign.getTruckNoDispatchMap(dispatchId);
        return map;
    }

    @ApiOperation(value="承运商分派运输订单给司机")
    @PostMapping("/addAppTruckOrder")
    public Map<String, Object> addAppTruckOrder(@RequestParam Integer dispatchId,
                                                @RequestParam Integer orderType,
                                                @RequestParam String capacityNumber,
                                                @RequestParam Integer carrierId) {
        Map<String, Object> map = omsFeign.addAppTruckOrder(dispatchId, orderType,capacityNumber, carrierId);
        return map;
    }
    //展示销售订单信息
    @ApiOperation(value="展示销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId()", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectSteelSaleForCarrier/{carrierId}")
    public Map<String, Object> selectSteelSaleForCarrier(@RequestBody(required=false) Map<String,Object> mapValue,
                                                         Integer apiId,
                                                         Integer pageNum,
                                                         Integer pageSize,
                                                         @PathVariable Integer carrierId

    )

    {
        return omsFeign.selectSteelSaleForCarrier(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, carrierId);
    }



    @ApiOperation(value=" 通过销售订单id查找信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(235)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectInfoBySaleOrderId/{saleOrderId}")
    public Map<String, Object> selectInfoBySaleOrderId(@RequestBody(required=false) Map<String,Object> mapValue,
                                                       Integer apiId,
                                                       Integer pageNum,
                                                       Integer pageSize,
                                                       @PathVariable Integer saleOrderId


    ){
        return  omsFeign.selectInfoBySaleOrderId(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,saleOrderId);
    }

    //展示发运计划信息
    @ApiOperation(value="展示发运计划信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId()", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectCokeRailPlan/{carrierId}")
    public Map<String, Object> selectCokeRailPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                                  Integer apiId,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  @PathVariable Integer carrierId,
                                                  Integer orderType

    ){
        return  omsFeign.selectCokeRailPlan(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, carrierId, orderType);
    }

    @ApiOperation(value=" 通过发运id查找信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId()", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectInfoByDayPlanId/{dayPlanId}")
    public Map<String, Object> selectInfoByDayPlanId(@RequestBody(required=false) Map<String,Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     @PathVariable  Integer dayPlanId,
                                                     Integer orderType


    ){
        return omsFeign.selectInfoByDayPlanId(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, dayPlanId, orderType);
    }

    @ApiOperation(value="根据运单id关闭订单")
    @PostMapping("/closeOmstruckOrder")
    public Map<String, Object> closeOmstruckOrder(@RequestBody Map<String,Object> mapVal) {
        Map<String, Object> map = omsFeign.closeOmstruckOrder(mapVal);
        return map;
    }

    @ApiOperation(value="根据运单id修改运力")
    @PostMapping("/updateCapacityId")
    public Map<String, Object> updateCapacityId(@RequestBody Map<String,Object> map) {
       return omsFeign.updateCapacityId(map);

    }

    @ApiOperation(value="siji")
    @PostMapping("/getCapacityAndDriverList")
    public Map<String, Object> getCapacityAndDriverList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                        Integer apiId,
                                                        Integer pageNum,
                                                        Integer pageSize,
                                                        String con,
                                                        String carrierId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        Map<String, Object> map = omsFeign.getCapacityAndDriverList(mapValue, apiId, pageNum, pageSize, con,carrierId);
        return map;
    }

    //查询所有的收货单位
    @GetMapping("/getReceivingUnit")
    public Map<String, Object> getReceivingUnit(){
        return omsFeign.getReceivingUnit();
    }


    //查询所有的发货单位（供应商）
    @GetMapping("/getSupplier")
    public Map<String, Object> getSupplier(){
        return omsFeign.getSupplier();
    }

    @ApiOperation(value = "关闭订单")
    @PostMapping("/CloseOrder")
    public  Map<String,Object> CloseOrder(@RequestBody(required = false)Map<String,Object> map){
        return  omsFeign.CloseOrder(map);
    }

    @ApiOperation(value = "分解内转计划（新增运输订单）")
    @PostMapping("/addInwardOrder")
    public Map<String,Object> addInwardOrder(@RequestBody Map<String,Object> mapValue) {
        return omsFeign.addInwardOrder(mapValue);
    }

    @ApiOperation(value = "分派计划")
    @PostMapping("/apportionInwardOrder")
    public Map<String,Object> apportionInwardOrder(@RequestBody List<Map<String,Object>> mapList) {
        return omsFeign.apportionInwardOrder(mapList);
    }

    @ApiOperation(value="分解计划查询")
    @PostMapping("/getInwardOrderList")
    public Map<String, Object> getInwardOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                  Integer apiId,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  Integer orderStatus,
                                                  String carrierId,
                                                  String con,
                                                  String startTime,
                                                  String endTime) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        Map<String, Object> map = omsFeign.getInwardOrderList(mapValue, apiId, pageNum, pageSize,orderStatus,carrierId, con,startTime,endTime);
        return map;
    }

    @ApiOperation(value="采购内转运单")
    @PostMapping("/getPurInwardOrderList")
    public Map<String, Object> getPurInwardOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                  Integer apiId,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  Integer orderStatus,
                                                  String carrierId,
                                                  String con,
                                                     Integer planEnableStatus,
                                                     String userId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        Map<String, Object> map = omsFeign.getPurInwardOrderList(mapValue, apiId, pageNum, pageSize,orderStatus,carrierId, con,planEnableStatus,userId);
        return map;
    }

    @ApiOperation(value = "司机APP端查询下发给自己运输订单")
    @PostMapping("/sendOrderToApp")
    public List<Map<String,Object>> sendOrderToApp(@RequestParam String capacityNumber) {
        return omsFeign.sendOrderToApp(capacityNumber);
    }

    @ApiOperation(value = "根据运输订单号查询订单物资")
    @PostMapping("/getUnloadOrderMaterial")
    public Map<String,Object> getUnloadOrderMaterial(@RequestBody(required = false)Map<String,Object>map){
        return omsFeign.getUnloadOrderMaterial(map);
    }
    @ApiOperation(value = "根据运输订单号查询卸货点")
    @PostMapping("/getUnloadOrderWarehouseName")
    public Map<String,Object> getUnloadOrderWarehouseName(@RequestBody(required = false)Map<String,Object>map){
        return omsFeign.getUnloadOrderWarehouseName(map);
    }

    @ApiOperation(value = "分解异地库计划")
    @PostMapping("/apportionInwardOffsetOrder")
    public Map<String,Object> apportionInwardOffsetOrder(@RequestBody Map<String,Object> mapvalue) {
        return omsFeign.apportionInwardOffsetOrder(mapvalue);
    }

    @ApiOperation(value = "查询司机的所有运输订单信息")
    @PostMapping("/getAllOrderMessage")
    public List<Map<String,Object>> getAllOrderMessage(@RequestParam String capacityNumber) {
        return omsFeign.getAllOrderMessage(capacityNumber);
    }

    @ApiOperation(value = "司机确认订单")
    @PostMapping("/driverConfirmation")
    public Map<String,Object> driverConfirmation(@RequestBody(required = false) Map<String,Object> mapvalue) {
        return omsFeign.driverConfirmation(mapvalue);
    }
    @ApiOperation(value = "通过运输订单号查询订单信息给司机")
    @PostMapping("/getMessageToApp")
    public Map<String, Object> getMessageToApp(@RequestBody(required = false) Map<String,Object> mapvalue) {
        return omsFeign.getMessageToApp(mapvalue);
    }

    @ApiOperation(value = "通过车牌号查询所有已下发未接收的订单信息")
    @PostMapping("/getAllOrderMessagesByCapacityNum")
    public List<Map<String, Object>> getAllOrderMessagesByCapacityNum(@RequestBody(required = false) Map<String,Object> mapvalue){
        return  omsFeign.getAllOrderMessagesByCapacityNum(mapvalue);
    }

    @ApiOperation(value = "通过车牌号查询该车牌下所有已接收的订单ID")
    @PostMapping("/getReceiveOrderIdListByCapacityNum")
    public List<Integer> getReceiveOrderIdListByCapacityNum(@RequestBody(required = false) Map<String, Object> mapvalue) {
        return omsFeign.getReceiveOrderIdListByCapacityNum(mapvalue);
    }

    @ApiOperation(value = "通过车牌号查询该车牌下所有已接收的订单ID")
    @PostMapping("/getAllRefuseOrderNumberByCapacity")
    public List<Map<String, Object>> getAllRefuseOrderNumberByCapacity(@RequestBody(required = false) Map<String,Object> mapvalue){
        return omsFeign.getAllRefuseOrderNumberByCapacity(mapvalue);
    }

    @ApiOperation(value = "添加退货实绩关闭当前订单")
    @PostMapping("/returnOrderCloseOrder")
    public Map<String,Object> returnOrderCloseOrder(@RequestBody(required = false) Map<String, Object> map){
        return omsFeign.returnOrderCloseOrder(map);
    }

    @ApiOperation(value = "根据运单id查询实绩位置")
    @PostMapping("/getOrderResult")
    public List<Map<String, Object>> getOrderResult(@RequestBody Map<String,Object> map){
        return omsFeign.getOrderResult(map);
    }

    @ApiOperation(value = "装机查询所以已装车的订单信息")
    @PostMapping("/getLoadForLoadCarResult")
    public  Map<String, Object> getLoadForLoadCarResult(@RequestBody(required = false) Map<String, Object> map){
        return omsFeign.getLoadForLoadCarResult(map);
    }


    @ApiOperation(value = "查询未下发的零星物资订单")
    @PostMapping("/getOthersOrderMesToSend")
    public Map<String, Object> getOthersOrderMesToSend(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 Integer apiId,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer type,
                                                 Integer orderStatus,
                                                 String carrierId,
                                                 String  con,
                                                 String userId,
                                                 String usersId,
                                                       Integer type1,
                                                       String startTime,
                                                       String endTime) {
        return omsFeign.getOthersOrderMesToSend(mapValue==null?new HashMap<>(): mapValue, apiId, pageNum, pageSize, orderStatus, carrierId, type, con,userId,usersId,type1,startTime,endTime);
    }

    @ApiOperation(value = "修改运输订单方法：根据运输订单id修改运力id")
    @PostMapping("/updateOmstruckOrder")
    public Map<String, Object> updateOmstruckOrder(@RequestBody(required = false) Map<String,Object> map){
        Integer orderId = Integer.parseInt(map.get("orderId").toString()) ;
        map.remove("orderId");
        map.put("orderId",orderId);
        return omsFeign.updateOmstruckOrder(map);
    }

    @ApiOperation(value="承运商销售分派运输订单给司机")
    @PostMapping("/addSaleTruckOrder")
    public Map<String, Object> addSaleTruckOrder(@RequestBody Map<String,Object> mapValue) {
        Map<String, Object> map = omsFeign.addSaleTruckOrder(mapValue);
        return map;
    }

    @ApiOperation(value = "通过运单下的物资信息")
    @PostMapping("/getOrderMaterialList")
    public Map<String, Object> getOrderMaterialList(@RequestParam Integer orderId) {
        return omsFeign.getOrderMaterialList(orderId);
    }

    @ApiOperation(value = "该车牌号下的所有订单号 以及 订单ID")
    @PostMapping("/getCapacityAllOrder")
    public Map<String, Object> getCapacityAllOrder(String capacityNumber, String date){
        return omsFeign.getCapacityAllOrder(capacityNumber,date);
    }

    @ApiOperation(value = "根据运单id关闭运输订单")
    @PostMapping("/closeOrder")
    public Map<String, Object> closeOrder(@RequestParam Integer orderId) {
        return omsFeign.closeOrder(orderId);
    }

    @ApiOperation(value = "查询订单是否确认")
    @PostMapping("/getDriverConfirmation")
    public Map<String, Object> getDriverConfirmation(@RequestBody(required = false) Map<String,Object> map) {
        return omsFeign.getDriverConfirmation(map);
    }

    @ApiOperation(value = "一键删除多个订单")
    @PostMapping("/deleteOrders")
    public Map<String, Object>  deleteOrders(@RequestBody(required = false) Map<String, Object> map){
        return omsFeign.deleteOrders(map);
    }

    @ApiOperation(value = "装卸工查询自己所有装了货的订单信息")
    @PostMapping("/getAllLoadUnloadResult")
    public Map<String, Object> getAllLoadUnloadResult(@RequestBody(required = false) Map<String, Object> mapValue){
        return omsFeign.getAllLoadUnloadResult(mapValue);
    }

    @ApiOperation(value = "计时作业查看订单详情")
    @PostMapping("/getTimeTaskEnd")
    public Map<String, Object> getTimeTaskEnd(@RequestBody(required = false) Map<String, Object> mapValue){
        return omsFeign.getTimeTaskEnd(mapValue);
    }

    @ApiOperation(value = "计时作业查看订单详情")
    @PostMapping("/getTimeTaskEndDetail")
    public Map<String, Object> getTimeTaskEndDetail(@RequestBody(required = false) Map<String, Object> mapValue){
        return omsFeign.getTimeTaskEndDetail(mapValue);
    }


    @ApiOperation(value = "计时作业查看订单详情")
    @PostMapping("/getPauseTimeTaskDetail")
    public Map<String, Object> getPauseTimeTaskDetail(@RequestParam("orderId") Integer orderId){
        return omsFeign.getPauseTimeTaskDetail(orderId);
    }

    @ApiOperation(value="批量关闭运输订单")
    @PostMapping("/batchCloseOrder")
    public Map<String, Object> batchCloseOrder(@RequestBody List<Map<String,Object>> mapList) {
        return omsFeign.batchCloseOrder(mapList);
    }

    @ApiOperation(value = "根据订单ID查询订单子表物资信息")
    @PostMapping("/getOrderMaterial/{orderId}")
    public Map<String,Object> getOrderMaterial(@PathVariable("orderId")Integer orderId){
        return omsFeign.getOrderMaterial(orderId);
    }


    @ApiOperation(value = "正常关闭运输订单")
    @PostMapping("/closeInwardOrder")
    public Map<String, Object> closeInwardOrder(Integer orderId){
        return omsFeign.closeInwardOrder(orderId);
    }

    @ApiOperation(value = "计时查询进程")
    @PostMapping("/getTimeOrderResult")
    public Map<String, Object> getTimeOrderResult(@RequestBody(required = false) Map<String, Object> map){
        return omsFeign.getTimeOrderResult(map);
    }

    @ApiOperation(value = "装机查询所以已装车的订单信息")
    @PostMapping("/getCapacityTypeByUserId")
    public Map<String, Object> getCapacityTypeByUserId(@RequestBody (required = false) Map<String, Object> map) {
        return omsFeign.getCapacityTypeByUserId(map);
    }

    @ApiOperation(value = "查询钢材订单号")
    @GetMapping("getSteelOrderNum")
    public Map<String, Object> getSteelOrderNum(String capacityId){
        return omsFeign.getSteelOrderNum(capacityId);
    }

    @ApiOperation(value = "查询钢材订单信息")
    @GetMapping("getMesToSteelDepartment")
    public Map<String, Object> getMesToSteelDepartment(Integer orderId){
        return omsFeign.getMesToSteelDepartment(orderId);
    }

    @ApiOperation(value = "查询钢材订单信息")
    @PostMapping("updateMaterialMes")
    public Map<String, Object> updateMaterialMes(@RequestBody(required = false) Map<String, Object> map) {
        return omsFeign.updateMaterialMes(map);
    }

    @ApiOperation(value = "修改正在装的状态")
    @PostMapping("/updateContinueStaus")
    public Map<String, Object> updateContinueStaus(@RequestBody(required = false) Map<String, Object> map) {
        return omsFeign.updateContinueStaus(map);
    }

    @ApiOperation(value = "展示销售订单下的运输订单")
    @PostMapping("getDriverInfoForSale2")
    public Map<String, Object> getDriverInfoForSale2(@RequestBody(required = false) Map<String, Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer saleOrderId,
                                                     String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return omsFeign.getDriverInfoForSale2(mapValue,apiId,pageNum,pageSize,new BigDecimal(saleOrderId),con);
    }

    @ApiOperation(value = "通过运单id或者运单号查询车辆是否放行")
    @PostMapping("canCapacityEnfactory")
    public Map<String, Object> canCapacityEnfactory(@RequestBody Map<String, Object> mapValue) {
        return omsFeign.canCapacityEnfactory(mapValue);
    }

    @ApiOperation(value = "出库信息")
    @PostMapping("getWarehouseMes")
    public Map<String, Object> getWarehouseMes(@RequestBody(required = false) Map<String, Object> mapValue,
                                               @RequestParam(required = false) String startTime,
                                               @RequestParam(required = false) String endTime,
                                               @RequestParam(required = false) String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return omsFeign.getWarehouseMes(mapValue,startTime,endTime, con);
    }

    @ApiOperation(value = "通过运单下的物资信息")
    @PostMapping("/closeInwardOrderByPlan")
    public  Map<String, Object> closeInwardOrderByPlan(@RequestParam Integer planId) {
        return omsFeign.closeInwardOrderByPlan(planId);
    }


    @ApiOperation(value = "查询内转钢材异地库物资详情")
    @GetMapping("/getOrderTrainMes")
    public Map<String,Object> getOrderTrainMes(@RequestParam Integer orderId){
        return omsFeign.getOrderTrainMes(orderId);
    }

    @ApiOperation(value = "查询内转钢材火车发运明细")
    @PostMapping("getWagonShippingDetails")
    public Map<String,Object> getWagonShippingDetails(@RequestBody(required = false)  Map<String,Object> map,
                                                      @RequestParam(required = false) String startTime,
                                                      @RequestParam(required = false) String endTime,
                                                      @RequestParam(required = false) String sendStation,
                                                      @RequestParam(required = false) String toTheStation,
                                                      @RequestParam(required = false) String consigneeName,
                                                      @RequestParam(required = false) String wagonNo){
        if (map == null) {
            map = new HashMap<>();
        }
        return omsFeign.getWagonShippingDetails(map,startTime,endTime,sendStation,toTheStation,consigneeName,wagonNo);
    }
}
