package com.steerinfo.dil.controller;

import com.steerinfo.dil.config.ImageFileUtils;
import com.steerinfo.dil.feign.TmsshipFeign;
import com.steerinfo.dil.feign.TmsTrainFeign;
import com.steerinfo.dil.feign.TmsTruckFeign;
import com.steerinfo.dil.mapper.UniversalMapper;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.websocket.server.ServerEndpoint;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Callable;

/**
 * @author luobang
 * @create 2021-09-17 14:11
 */

@RestController
@RequestMapping("${api.version}/tms")
public class TMSController extends BaseRESTfulController {
    @Autowired
    private TmsTruckFeign tmsTruckFeign;
    @Autowired
    private TmsTrainFeign tmsTrainFeign;
    @Autowired
    TmsshipFeign tmsshipFeign;
    @Autowired
    UniversalMapper universalMapper;
    @Autowired
    private ImageFileUtils imageFileUtils;
    /*======================================船运==========================================*/

    /**
     * 驳船
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getBargeOperationList")
    @ApiOperation(value = "展示驳船")
    public Map<String, Object> getBargeOperationList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getBargeOperationList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("selectBargeOperation/{bargeOperationId}")
    @ApiOperation(value = "通过id查询驳船")
    Map<String, Object> selectBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId) {
        return tmsshipFeign.selectBargeOperation(bargeOperationId);
    }

    @PostMapping("getBargeOperation/{bargeOperationId}")
    @ApiOperation(value = "查询驳船")
    Map<String, Object> getBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId) {
        return tmsshipFeign.getBargeOperation(bargeOperationId);
    }

    @PostMapping("deleteBargeOperation/{bargeOperationId}")
    @ApiOperation(value = "逻辑删除驳船")
    Map<String, Object> deleteBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId) {
        return tmsshipFeign.deleteBargeOperation(bargeOperationId);
    }

    @PostMapping("updateBargeOperation")
    @ApiOperation(value = "修改驳船")
    Map<String, Object> updateBargeOperation(@RequestBody Map<String, Object> tmsshipBargeOperation) {
        return tmsshipFeign.updateBargeOperation(tmsshipBargeOperation);
    }

    @PostMapping("addBargeOperation")
    @ApiOperation(value = "新增驳船")
    Map<String, Object> addBargeOperation(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addBargeOperation(map);
    }

    @PostMapping("addTmsShipEntryWharyResult")
    @ApiOperation(value = "新增抵港")
    Map<String, Object> addTmsShipEntryWharyResult(@RequestBody Map<String, Object> mapVal) {
        return tmsshipFeign.addTmsShipEntryWharyResult(mapVal);
    }

    @PostMapping("addTmsShipOutWharyResult")
    @ApiOperation(value = "新增离港")
    Map<String, Object> addTmsShipOutWharyResult(@RequestBody Map<String, Object> mapVal) {
        return tmsshipFeign.addTmsShipOutWharyResult(mapVal);
    }

    /**
     * 装船
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getLoadShipList")
    @ApiOperation(value = "展示装船")
    public Map<String, Object> getLoadShipList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId,
                                               Integer status,
                                               @RequestParam(required = false) String con,
                                               String startTime,
                                               String endTime) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getLoadShipList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,status,con,startTime,endTime);
    }

    @PostMapping("getLoadShip/{resultId}")
    @ApiOperation(value = "查询装船")
    Map<String, Object> getLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.getLoadShip(resultId);
    }

    @PostMapping("selectLoadShip/{resultId}")
    @ApiOperation(value = "通过id查询装船")
    Map<String, Object> selectLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.selectLoadShip(resultId);
    }

    @PostMapping("deleteLoadShip/{resultId}")
    @ApiOperation(value = "逻辑删除装船")
    Map<String, Object> deleteLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.deleteLoadShip(resultId);
    }

    @PostMapping("updateLoadShip")
    @ApiOperation(value = "修改装船")
    Map<String, Object> updateLoadShip(@RequestBody Map<String, Object> tmsshipLoadShipResult) {
        return tmsshipFeign.updateLoadShip(tmsshipLoadShipResult);
    }

    @PostMapping("addLoadShip")
    @ApiOperation(value = "新增装船")
    Map<String, Object> addLoadShip(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addLoadShip(map);
    }

    /**
     * 位置作业
     *
     * @param mapValue
     * @return
     */
    @PostMapping("getShipLocationList")
    @ApiOperation(value = "展示位置作业")
    public Map<String, Object> getShipLocationList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                   String con
                                                   ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getShipLocationList(mapValue==null?new HashMap<>():mapValue,con);
    }

    @PostMapping("getShipLocation/{locationId}")
    @ApiOperation(value = "查询位置作业")
    Map<String, Object> getShipLocation(@PathVariable("locationId") BigDecimal locationId) {
        return tmsshipFeign.getShipLocation(locationId);
    }

    @PostMapping("/getWareHouseOutresult/{resultId}")
    @ApiOperation(value = "查询港口出库")
    Map<String, Object> getWareHouseOutresult(@PathVariable("resultId") BigDecimal resultId) {
        return tmsTrainFeign.getWareHouseOutresult(resultId);
    }

    @PostMapping("selectShipLocation/{locationId}")
    @ApiOperation(value = "通过id查询位置作业")
    Map<String, Object> selectShipLocation(@PathVariable("locationId") BigDecimal locationId) {
        return tmsshipFeign.selectShipLocation(locationId);
    }

    @PostMapping("deleteShipLocation/{locationId}")
    @ApiOperation(value = "逻辑删除位置作业")
    Map<String, Object> deleteShipLocation(@PathVariable("locationId") BigDecimal locationId) {
        return tmsshipFeign.deleteShipLocation(locationId);
    }

    @PostMapping("updateShipLocation")
    @ApiOperation(value = "修改位置作业")
    Map<String, Object> updateShipLocation(@RequestBody Map<String, Object> tmsshipShipLocation) {
        return tmsshipFeign.updateShipLocation(tmsshipShipLocation);
    }

    @PostMapping("addShipLocation")
    @ApiOperation(value = "新增位置作业")
    Map<String, Object> addShipLocation(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addShipLocation(map);
    }

    /**
     * 水路货物运单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("listAllOrders")
    @ApiOperation(value = "展示水路货物运单")
    public Map<String, Object> listAllOrders(@RequestBody(required = false) Map<String, Object> mapValue,
                                             Integer pageNum,
                                             Integer pageSize,
                                             Integer apiId,
                                             String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.listAllOrders(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,con);
    }


    @PostMapping("/getBatchList")
    public Map<String, Object> getBatchList(@RequestBody(required = false) Map<String, Object> mapValue,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer apiId){
        return  tmsshipFeign.getBatchList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId);
    }


    //为提货委托查询批次
    @PostMapping("/getBatchListForAttorney")
    public Map<String, Object> getBatchListForAttorney(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId,
                                          String con){
        return  tmsshipFeign.getBatchListForAttorney(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId, con);
    }

    //为装船指令查询批次
    @PostMapping("/getBatchListForInstruction")
    public Map<String, Object> getBatchListForInstruction(@RequestBody(required = false) Map<String, Object> mapValue,
                                                       Integer pageNum,
                                                       Integer pageSize,
                                                       Integer apiId,
                                                       String con){
        return  tmsshipFeign.getBatchListForInstruction(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId, con);
    }


    //框计算计算货权转移中出现的批次
    @PostMapping("/getBatchIdByForeign")
    public Map<String, Object> getBatchIdByForeign(@RequestBody(required = false) Map<String, Object> mapValue,
                                                       Integer pageNum,
                                                       Integer pageSize,
                                                       Integer apiId,
                                                       String con){
        return  tmsshipFeign.getBatchIdByForeign(mapValue==null?new HashMap<String, Object>():mapValue, pageNum, pageSize, apiId, con);
    }



    /**
     * 展示船只信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getCapacityList")
    @ApiOperation(value = "展示船只信息")
    public Map<String, Object> getCapacityList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId,
                                               String con) {
        return tmsshipFeign.getCapacityList(mapValue==null?new HashMap<String, Object>():mapValue,pageNum, pageSize, apiId,con);
    }


    @PostMapping(value = "/uploadCargoPic")
    public String uploadCargoPic(@RequestParam ("file") MultipartFile multipartFile){
        return tmsshipFeign.uploadCargoPic(multipartFile);
    }

    /**
     * 卸船作业
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getUnLoadShipList")
    @ApiOperation(value = "展示卸船作业信息列表")
    public Map<String, Object> getUnLoadShipList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer apiId,
                                                 String con) {

        return tmsshipFeign.getUnLoadShipList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,con);
    }

    @PostMapping("getUnloadShip/{resultId}")
    @ApiOperation(value = "查询卸船作业")
    Map<String, Object> getUnloadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.getUnloadShip(resultId);
    }

    @PostMapping("selectUnLoadShip/{resultId}")
    @ApiOperation(value = "通过id查询卸船作业")
    Map<String, Object> selectUnLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.selectUnLoadShip(resultId);
    }

    @PostMapping("deleteUnLoadShip/{resultId}")
    @ApiOperation(value = "逻辑删除卸船作业")
    Map<String, Object> deleteUnLoadShip(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.deleteUnLoadShip(resultId);
    }

    @PostMapping("updateUnLoadShip")
    @ApiOperation(value = "修改卸船作业")
    Map<String, Object> updateUnLoadShip(@RequestBody Map<String, Object> tmsshipUnloadShipResult) {
        return tmsshipFeign.updateUnLoadShip(tmsshipUnloadShipResult);
    }

    @PostMapping("addUnLoadShip")
    @ApiOperation(value = "新增卸船作业")
    Map<String, Object> addUnLoadShip(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.addUnLoadShip(map);
    }

    /**
     * 水分质检
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getWaterQualityResultList")
    @ApiOperation(value = "展示水分质检信息列表")
    public Map<String, Object> getWaterQualityResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                         Integer pageNum,
                                                         Integer pageSize,
                                                         Integer apiId,
                                                         @RequestParam(required = false) String con) {

        return tmsshipFeign.getWaterQualityResultList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId, con);
    }

    @PostMapping("getWaterQuality/{resultId}")
    @ApiOperation(value = "查询水分质检")
    Map<String, Object> getWaterQuality(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.getWaterQuality(resultId);
    }

    @PostMapping("selectWaterQualityResult/{resultId}")
    @ApiOperation(value = "通过id查询水分质检")
    Map<String, Object> selectWaterQualityResult(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.selectWaterQualityResult(resultId);
    }

    @PostMapping("deleteWaterQualityResult/{resultId}")
    @ApiOperation(value = "逻辑删除水分质检")
    Map<String, Object> deleteWaterQualityResult(@PathVariable("resultId") BigDecimal resultId) {
        return tmsshipFeign.deleteWaterQualityResult(resultId);
    }

    @PostMapping("updateWaterQualityResult")
    @ApiOperation(value = "修改水分质检")
    Map<String, Object> updateWaterQualityResult(@RequestBody Map<String, Object> tmsshipWaterQualityResult) {
        return tmsshipFeign.updateWaterQualityResult(tmsshipWaterQualityResult);
    }

    @PostMapping("addWaterQualityResult")
    @ApiOperation(value = "新增水分质检")
    Map<String, Object> addWaterQualityResult(@RequestBody Map<String, Object> map) {
        Map<String, Object> stringObjectMap = tmsshipFeign.addWaterQualityResult(map);
        return stringObjectMap;
    }

    /**
     * 船只信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getCapacities")
    @ApiOperation(value = "展示船只信息列表")
    public Map<String, Object> getCapacities(BigDecimal instructionsId,
                                             @RequestBody(required = false) Map<String, Object> mapValue,
                                             Integer pageNum,
                                             Integer pageSize,
                                             Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getCapacities(instructionsId, mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("getInstructionsCapacity/{instructionsCapacityId}")
    @ApiOperation(value = "查询船只信息")
    Map<String, Object> getInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId) {
        return tmsshipFeign.getInstructionsCapacity(instructionsCapacityId);
    }

    @PostMapping("deleteInstructionsCapacity/{instructionsCapacityId}")
    @ApiOperation(value = "逻辑删除船只信息")
    Map<String, Object> deleteInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId) {
        return tmsshipFeign.deleteInstructionsCapacity(instructionsCapacityId);
    }

    @PostMapping("updateInstructionsCapacity")
    @ApiOperation(value = "修改船只信息")
    Map<String, Object> updateInstructionsCapacity(@RequestBody Map<String, Object> omsshipInstructionsCapacity) {
        return tmsshipFeign.updateInstructionsCapacity(omsshipInstructionsCapacity);
    }

    @PostMapping("addInstructionsCapacity")
    @ApiOperation(value = "新增船只信息")
    Map<String, Object> addInstructionsCapacity(@RequestBody Map<String, Object> omsshipInstructionsCapacity) {
        return tmsshipFeign.addInstructionsCapacity(omsshipInstructionsCapacity);
    }

    /**
     * 装船指令
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getShipMentInstructionsList")
    @ApiOperation(value = "展示装船指令列表")
    public Map<String, Object> getShipMentInstructionsList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                           Integer pageNum,
                                                           Integer pageSize,
                                                           Integer apiId,
                                                           String status,
                                                           String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getShipMentInstructionsList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,status,con);
    }

    @PostMapping("getShipmentInstructions/{instructionsId}")
    @ApiOperation(value = "下发装船指令")
    Map<String, Object> getShipmentInstructions(@PathVariable("instructionsId") BigDecimal instructionsId) {
        return tmsshipFeign.getShipmentInstructions(instructionsId);
    }

    @PostMapping("deleteByPrimaryKey/{instructionsId}")
    @ApiOperation(value = "逻辑删除装船指令")
    Map<String, Object> deleteByPrimaryKey(@PathVariable("instructionsId") BigDecimal instructionsId) {
        return tmsshipFeign.deleteByPrimaryKey(instructionsId);
    }

    @PostMapping("sendShipmentInstructionsStatus/{shipmentInstructionsId}")
    @ApiOperation(value = "修改状态")
    Map<String, Object> sendShipmentInstructionsStatus(@PathVariable("shipmentInstructionsId") BigDecimal shipmentInstructionsId) {
        return tmsshipFeign.sendShipmentInstructionsStatus(shipmentInstructionsId);
    }

    @PostMapping("updateShipmentInstructions")
    @ApiOperation(value = "修改装船指令")
    Map<String, Object> updateShipmentInstructions(@RequestBody Map<String, Object> omsshipShipmentInstructions) {
        return tmsshipFeign.updateShipmentInstructions(omsshipShipmentInstructions);
    }

    @PostMapping("addShipmentInstructions")
    @ApiOperation(value = "新增装船指令")
    Map<String, Object> addShipmentInstructions(@RequestBody Map<String, Object> omsshipShipmentInstructions) {
        return tmsshipFeign.addShipmentInstructions(omsshipShipmentInstructions);
    }

    /**
     * 货权转移
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getAmsshipCargoTranferResultList")
    @ApiOperation(value = "展示货权转移")
    public Map<String, Object> getAmsshipCargoTranferResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                                Integer pageNum,
                                                                Integer pageSize,
                                                                Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getAmsshipCargoTranferResultList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("getGroupList")
    @ApiOperation(value = "展示收货人列表")
    @ApiImplicitParams(
            @ApiImplicitParam(name="apiId",value="217")
    )
    public Map<String, Object> getGroupList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                                Integer pageNum,
                                                                Integer pageSize,
                                                                Integer apiId,
                                                                String con) {

        return tmsshipFeign.getGroupList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,con);
    }
    @PostMapping("getMaterialList")
    @ApiOperation(value = "展示物资列表")
    @ApiImplicitParams(
            @ApiImplicitParam(name="apiId",value="216")
    )
    public Map<String, Object> getMaterialList(@RequestBody(required = false) Map<String, Object> mapValue,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer apiId,
                                            String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getMaterialList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,con);
    }
    @PostMapping("selectShippeByName")
    @ApiOperation(value = "展示货权转移送达单位列表")
    @ApiImplicitParams(
            @ApiImplicitParam(name = "apiId",value = "215")
    )
    public Map<String, Object> selectShippeByName(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId,
                                               String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.selectShippeByName(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,con);
    }
    @PostMapping("insertamsshipCargoTransferResult")
    @ApiOperation(value = "新增货权转移")
    Map<String, Object> insertamsshipCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult) {
        return tmsshipFeign.insertamsshipCargoTransferResult(amsshipCargoTransferResult);
    }

    @PostMapping("deleteByCargoId/{cargoTransferResultId}")
    @ApiOperation(value = "逻辑删除货权转移")
    Map<String, Object> deleteByCargoId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId) {
        return tmsshipFeign.deleteByCargoId(cargoTransferResultId);
    }

    @PostMapping("editCargoTransferResult")
    @ApiOperation(value = "修改货权转移")
    Map<String, Object> editCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult) {
        return tmsshipFeign.editCargoTransferResult(amsshipCargoTransferResult);
    }

    @PostMapping("selectByCargoTranferResultId/{cargoTransferResultId}")
    @ApiOperation(value = "通过id查询货权转移")
    Map<String, Object> selectByCargoTranferResultId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId) {
        return tmsshipFeign.selectByCargoTranferResultId(cargoTransferResultId);
    }

    /**
     * 提货委托
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getAmsshipDeliveryAttroneyList")
    @ApiOperation(value = "展示提货委托")
    public Map<String, Object> getAmsshipDeliveryAttroneyList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                              Integer pageNum,
                                                              Integer pageSize,
                                                              Integer apiId,
                                                              Integer status,
                                                              String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getAmsshipDeliveryAttroneyList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,status,con);
    }

    @PostMapping("insertshipDeliveryAttorney")
    @ApiOperation(value = "新增提货委托")
    Map<String, Object> insertshipDeliveryAttorney(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.insertshipDeliveryAttorney(map);
    }

    @PostMapping("deleteByAttorneyId/{attorneyId}")
    @ApiOperation(value = "逻辑删除提货委托")
    Map<String, Object> deleteByAttorneyId(@PathVariable("attorneyId") Integer attorneyId) {
        return tmsshipFeign.deleteByAttorneyId(attorneyId);
    }

    @PostMapping("editDeliveryAttroney")
    @ApiOperation(value = "修改提货委托")
    Map<String, Object> editDeliveryAttroney(@RequestBody Map<String, Object> amsshipDeliveryAttorney) {
        return tmsshipFeign.editDeliveryAttroney(amsshipDeliveryAttorney);
    }

    @PostMapping("getDeliveryAttorneyId/{attorneyId}")
    @ApiOperation(value = "通过id查询提货委托")
    Map<String, Object> getDeliveryAttorneyId(@PathVariable("attorneyId") Integer attorneyId) {
        return tmsshipFeign.getDeliveryAttorneyId(attorneyId);
    }

    @PostMapping("sendDeliveryAttorneyStatus/{attorneyId}")
    @ApiOperation(value = "下发提货委托")
    Map<String, Object> sendDeliveryAttorneyStatus(@PathVariable("attorneyId") Integer attorneyId) {
        return tmsshipFeign.sendDeliveryAttorneyStatus(attorneyId);
    }

    /**
     * 放货通知
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getshipDeliveryNoticeList")
    @ApiOperation(value = "展示放货通知")
    public Map<String, Object> getshipDeliveryNoticeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                         Integer pageNum,
                                                         Integer pageSize,
                                                         Integer apiId,
                                                         Integer status,
                                                         @RequestParam(required = false) String con,
                                                         @RequestParam(required = false) String startTime,
                                                         @RequestParam(required = false) String endTime) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsshipFeign.getshipDeliveryNoticeList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,status,con,startTime,endTime);
    }

    @PostMapping("insertDeliveryNotice")
    @ApiOperation(value = "新增放货通知")
    Map<String, Object> insertDeliveryNotice(@RequestBody Map<String, Object> amsshipDeliveryNotice) {
        return tmsshipFeign.insertDeliveryNotice(amsshipDeliveryNotice);
    }

    @PostMapping("deleteByNoticeId/{noticeId}")
    @ApiOperation(value = "逻辑删除放货通知")
    Map<String, Object> deleteByNoticeId(@PathVariable("noticeId") Integer noticeId) {
        return tmsshipFeign.deleteByNoticeId(noticeId);
    }

    @PostMapping("editDeliveryNotice")
    @ApiOperation(value = "修改放货通知")
    Map<String, Object> editDeliveryNotice(@RequestBody Map<String, Object> editDeliveryNotice) {
        return tmsshipFeign.editDeliveryNotice(editDeliveryNotice);
    }

    @PostMapping("selectByNoticeId/{noticeId}")
    @ApiOperation(value = "通过id查询放货通知")
    Map<String, Object> selectByNoticeId(@PathVariable("noticeId") Integer noticeId) {
        return tmsshipFeign.selectByNoticeId(noticeId);
    }

    @PostMapping("sendDeliveryNotice/{noticeId}")
    @ApiOperation(value = "下发放货通知")
    Map<String, Object> sendDeliveryNotice(@PathVariable("noticeId") Integer noticeId) {
        return tmsshipFeign.sendDeliveryNotice(noticeId);
    }
    //船舶动态表
    @PostMapping("/selectAllShipDynamaics")
    Map<String, Object> selectAllShipDynamaics(@RequestBody(required = false) Map<String,Object> map,
                                               String con){
        if (map==null){
            map=new HashMap<>();
        }
        return tmsshipFeign.selectAllShipDynamaics(map,con);
    }

    //万州港装车数据
    @PostMapping("/getLoadData")
    Map<String, Object> getLoadData(@RequestBody(required = false) Map<String,Object> map){
        if (map==null){
            map=new HashMap<>();
        }
        return tmsshipFeign.getLoadData(map);
    }

    //万州港卸船数据
    @PostMapping("/getUnloadData")
    Map<String, Object> getUnloadData(@RequestBody(required = false) Map<String,Object> map){
        if (map==null){
            map=new HashMap<>();
        }
        return tmsshipFeign.getUnloadData(map);
    }

    //下游港口船舶动态表
    @PostMapping("/getDownShipDynamaics")
    Map<String, Object> getDownShipDynamaics(@RequestBody(required = false) Map<String,Object> map){
        if (map==null){
            map=new HashMap<>();
        }
        return tmsshipFeign.getDownShipDynamaics(map);
    }

    @PostMapping("getControlLines")
    @ApiOperation(value = "查询控制线等闸")
    Map<String, Object> getControlLines(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.getControlLines(map);
    }

    @PostMapping("updateControlLine")
    @ApiOperation(value = "修改控制线等闸")
    Map<String, Object> updateControlLine(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.updateControlLine(map);
    }

    @PostMapping("getControlLinesTable")
    @ApiOperation(value = "控制线等闸表格")
    Map<String, Object> getControlLinesTable(@RequestBody Map<String, Object> map) {
        return tmsshipFeign.getControlLinesTable(map);
    }

    /**
     * 下拉框
     *
     * @return
     */
    @GetMapping("getGroupId")
    @ApiOperation(value = "得到下拉")
    public Map<String, Object> getGroupId() {
        return tmsshipFeign.getGroupId();
    }

    @GetMapping("getMaterialId")
    @ApiOperation(value = "得到物资ID下拉")
    public Map<String, Object> getMaterialId(){
        return tmsshipFeign.getMaterialId();
    }

    @GetMapping("getCargoId")
    @ApiOperation(value = "得到货物下拉")
    public Map<String, Object> getCargoId() {
        return tmsshipFeign.getCargoId();
    }

    @GetMapping("insertBetchId")
    @ApiOperation(value = "得到批次下拉")
    public Map<String, Object> insertBetchId() {
        return tmsshipFeign.insertBetchId();
    }

    @GetMapping("getAttorneyId")
    @ApiOperation(value = "得到提货下拉")
    public Map<String, Object> getAttorneyId() {
        return tmsshipFeign.getAttorneyId();
    }

    @GetMapping("getNoticeId")
    @ApiOperation(value = "得到放货下拉")
    public Map<String, Object> getNoticeId() {
        return tmsshipFeign.getNoticeId();
    }

    @GetMapping("getPortName")
    @ApiOperation(value = "得到货权转移单位")
    public Map<String, Object> getPortName() {
        return tmsshipFeign.getPortName();
    }

    @GetMapping("getPortId")
    @ApiOperation(value = "得到港口下拉")
    public Map<String, Object> getPortId() {
        return tmsshipFeign.getPortId();
    }

    @GetMapping("getRmRawId")
    @ApiOperation(value = "得到仓库下拉")
    public Map<String, Object> getRmRawId() {
        return tmsshipFeign.getRmRawId();
    }

    @GetMapping("getPierId")
    @ApiOperation(value = "得到码头下拉")
    public Map<String, Object> getPierId() {
        return tmsshipFeign.getPierId();
    }

    @ApiOperation(value = "查询特定所有的物资")
    @GetMapping("/getFuMaterial/{type}")
    public Map<String, Object> getFuMaterial(@PathVariable("type") Integer type) {
        return tmsTruckFeign.getFuMaterial(type);
    }

    @GetMapping("getResultNumber")
    @ApiOperation(value = "得到实绩编号下拉")
    public Map<String, Object> getResultNumber() {
        return tmsshipFeign.getResultNumber();
    }

    @GetMapping("getCarrier")
    @ApiOperation(value = "得到承运商下拉")
    public Map<String, Object> getCarrier() {
        return tmsshipFeign.getCarrier();
    }

    @GetMapping("getShipperId")
    @ApiOperation(value = "得到托运方下拉")
    public Map<String, Object> getShipperId() {
        return tmsshipFeign.getShipper();
    }

    @GetMapping("getOrderId")
    @ApiOperation(value = "得到装船指令下拉")
    public Map<String, Object> getTask() {
        return tmsshipFeign.getTask();
    }

    @GetMapping("getCapacityId")
    @ApiOperation(value = "得到船下拉")
    public Map<String, Object> getCapacityId() {
        return tmsshipFeign.getCapacityId();
    }


    /*======================================火运==========================================*/


    //************************************TmstrainLoadingResultController********************
    @ApiOperation(value = "查询装车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(58)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/getTmstrainWagonLoad")
    public Map<String, Object> getTmstrainWagonLoad(@RequestBody(required = false) Map<String, Object> mapValue,
                                                    Integer apiId,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    Integer resultType,
                                                    Integer materialId,
                                                    Integer supplierId,
                                                    String con,
                                                    String startTime,
                                                    String endTime) {
        return tmsTrainFeign.getTmstrainWagonLoad(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, resultType,materialId,supplierId, con,startTime,endTime);
    }


    @ApiOperation(value = "修改港口出库")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainLoadingResult", value = "车皮装车对象", required = false, dataType = "TmstrainLoadingResult")
    })
    @PostMapping(value = "/updateWarehouseResult")
    public Map<String, Object> updateWarehouseResult(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTrainFeign.updateWarehouseResult(map);
    }


    @ApiOperation(value = "新增车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainLoadingResult", value = "车皮装车对象", required = false, dataType = "TmstrainLoadingResult")
    })
    @PostMapping(value = "/insertTmstrainLoadingResult")
    public Map<String, Object> insertTmstrainLoadingResult(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTrainFeign.insertTmstrainLoadingResult(map);
    }


    @ApiOperation(value = "通过主键查询车皮装车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "车皮装车主键", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/getTmstrainLoadingResultByResultId/{resultId}")
    public Map<String, Object> getTmstrainLoadingResultByResultId(@PathVariable("resultId") BigDecimal resultId) {
        return tmsTrainFeign.getTmstrainLoadingResultByResultId(resultId);
    }

    @ApiOperation(value = "通过主键修改车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainLoadingResult", value = "修改车皮装车map", required = false, dataType = "TmstrainWagonLoadResult")
    })
    @PostMapping(value = "/upadteTmstrainLoadingResultByResultId")
    public Map<String, Object> upadteTmstrainLoadingResultByResultId(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTrainFeign.upadteTmstrainLoadingResultByResultId(map);
    }

    @ApiOperation(value = "通过主键删除车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "主键ID", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/deleteTmstrainLoadingResultByResultId")
    public Map<String, Object> deleteTmstrainLoadingResultByResultId(@RequestParam BigDecimal resultId) {
        return tmsTrainFeign.deleteTmstrainLoadingResultByResultId(resultId);
    }

    @ApiOperation(value = "通过主键删除车皮出库作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "主键ID", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/deleteOutBoundWagonById")
    public Map<String, Object> deleteOutBoundWagonById(@RequestParam BigDecimal resultId){
        return tmsTrainFeign.deleteOutBoundWagonById(resultId);
    }

    //********************下拉框**********************

    @ApiOperation(value = "获取发站地点名称")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getSendStationName")
    public Map<String, Object> getSendStationName() {
        return tmsTrainFeign.getSendStationName();
    }

    @ApiOperation(value = "获取到站地点名称")
    @GetMapping(value = "/getArrivalStationName")
    public Map<String, Object> getArrivalStationName() {
        return tmsTrainFeign.getArrivalStationName();
    }

    @ApiOperation(value = "装车新增港存库出库")
    @PostMapping(value = "/addWarehouseOutResult")
    public Map<String, Object> addWarehouseOutResult(@RequestBody(required = false) Map<String,Object> map) {
        return tmsTrainFeign.addWarehouseOutResult(map);
    }


    @ApiOperation(value = "获取批次ID")
    @GetMapping(value = "/getBatchId")
    public Map<String, Object> getBatchId() {
        return tmsTrainFeign.getBatchId();
    }


    @ApiOperation(value = "获取已装车还未卸车车皮")
    @PostMapping(value = "/getWagonNo/{resultType}")
    public Map<String, Object> getWagonNo(@PathVariable("resultType") Integer resultType,
                                          @RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String wagon,
                                          String purchaseOrderNum,
                                          String materialName){
        return tmsTrainFeign.getWagonNo(resultType, mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,wagon,purchaseOrderNum,materialName);
    }

    @ApiOperation(value = "查询所有发运计划")
    @GetMapping(value = "/getRailPlan")
    public Map<String, Object> getRailPlan() {
        return tmsTrainFeign.getRailPlan();
    }

    @GetMapping(value = "/getDilBatch")
    public Map<String, Object> getDilBatch() {
        return tmsTruckFeign.getDilBatch();
    }

    @GetMapping(value = "/getCarrierId")
    public Map<String, Object> getCarrierId() {
        return tmsTruckFeign.getCarrier();
    }

    @GetMapping(value = "/getLine")
    public Map<String, Object> getLine() {
        return tmsTruckFeign.getLine();
    }

    @GetMapping(value = "/getWarehouse")
    public Map<String, Object> getWarehouse() {
        return tmsTruckFeign.getWarehouse();
    }

    @GetMapping(value = "/getGatepost")
    public Map<String, Object> getGatepost() {
        return tmsTruckFeign.getGatepost();
    }

    @GetMapping(value = "/getAPO")
    public Map<String, Object> getAPO() {
        return tmsTruckFeign.getAPO();
    }

    @GetMapping(value = "/getFuCapacityId")
    public Map<String, Object> getFuCapacityId() {
        return tmsTruckFeign.getFuCapacityId();
    }

    @GetMapping(value = "/getPort")
    public Map<String, Object> getPort() {
        return tmsTruckFeign.getPort();
    }

    @ApiOperation(value = "查询卸货点")
    @GetMapping("/getUnloadPoint/{type}")
    public Map<String, Object> getUnloadPoint(@PathVariable("type") Integer type) {
        return tmsTruckFeign.getUnloadPoint(type);
    }

    @ApiOperation(value = "查询卸车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(60)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/getTmstrainWagonUnLoad")
    public Map<String, Object> getTmstrainWagonUnLoad(@RequestBody(required = false) Map<String, Object> mapValue,
                                                      Integer apiId,
                                                      Integer pageNum,
                                                      Integer pageSize,
                                                      Integer resultType,
                                                      String con) {
        return tmsTrainFeign.getTmstrainWagonUnLoad(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, resultType,con);
    }

    @ApiOperation(value = "通过主键删除车皮卸车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "unloadingId", value = "主键ID", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/deleteTmstrainWagonUnLoadResultByUnLoadingId")
    public Map<String, Object> deleteTmstrainWagonUnLoadResultByUnLoadingId(@RequestParam BigDecimal unloadingId) {
        return tmsTrainFeign.deleteTmstrainWagonUnLoadResultByUnLoadingId(unloadingId);
    }

    @ApiOperation(value = "新增车皮卸车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainWagonUnloadResult", value = "车皮卸车对象", required = false, dataType = "TmstrainWagonUnloadResult")
    })
    @PostMapping(value = "/insertTmstrainWagonUnLoadResult")
    public Map<String, Object> insertTmstrainWagonUnLoadResult(@RequestBody(required = false) Map<String, Object> tmstrainWagonUnloadResult) {
        return tmsTrainFeign.insertTmstrainWagonUnLoadResult(tmstrainWagonUnloadResult);
    }

    @ApiOperation(value = "通过主键修改车皮卸车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainWagonUnloadResult", value = "车皮卸车对象", required = false, dataType = "TmstrainWagonUnloadResult")
    })
    @PostMapping(value = "/upadteTmstrainWagonUnLoadResultByUnLoadingId")
    public Map<String, Object> upadteTmstrainWagonUnLoadResultByUnLoadingId(@RequestBody(required = false) Map<String, Object> tmstrainWagonUnloadResult) {
        return tmsTrainFeign.upadteTmstrainWagonUnLoadResultByUnLoadingId(tmstrainWagonUnloadResult);
    }

    @ApiOperation(value = "查看火运实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(65)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/getTmstrainresult")
    public Map<String, Object> getTmstrainresult(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 Integer apiId,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 String con) {
        return tmsTrainFeign.getTmstrainresult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize,con);
    }

    @ApiOperation(value = "通过主键查询车皮卸车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "unloadingId", value = "车皮卸车主键", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/getTmstrainWagonUnLoadResultByUnLoadingId/{unloadingId}")
    public Map<String, Object> getTmstrainWagonUnLoadResultByUnLoadingId(@PathVariable("unloadingId") BigDecimal unloadingId) {
        return tmsTrainFeign.getTmstrainWagonUnLoadResultByUnLoadingId(unloadingId);
    }

    //下拉框
    @ApiOperation(value = "获取卸车地点名称")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getUnloadingPointName")
    public Map<String, Object> getUnloadingPointName() {
        return tmsTrainFeign.getUnloadingPointName();
    }


    //下拉框
    @ApiOperation(value = "获取货权转移图片")
    @ApiImplicitParams({
    })
    @PostMapping(value = "/downLoadDeilveryNotice")
    public Map<String, Object> downLoadDeilveryNotice(@RequestParam Integer noticeId) {
        return tmsshipFeign.downLoadDeilveryNotice(noticeId);
    }

    @ApiOperation(value = "获取卸车路径名称")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getUnloadingRouteName")
    public Map<String, Object> getUnloadingRouteName() {
        return tmsTrainFeign.getUnloadingRouteName();
    }


    @ApiOperation(value = "查询请车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(57)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllWagonPlease")
    public Map<String, Object> getAllWagonPlease(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 Integer apiId,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer status,
                                                 Integer resultType,
                                                 Integer resultId,
                                                 String con) {

        return tmsTrainFeign.getAllWagonPlease(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, status, resultType,resultId,con);
    }

    @ApiOperation(value = "通过Id查询请车作业")
    @PostMapping("/getWagonPleaseById/{resultId}")
    public Map<String, Object> getWagonPleaseById(@PathVariable("resultId") Integer resultId) {
        return tmsTrainFeign.getWagonPleaseById(resultId);
    }

    @ApiOperation(value = "新增请车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amstrainWagonPlease", value = "请车作业对象", required = false, dataType = "AmstrainWagonPlease"),
    })
    @PostMapping("/addWagonPlease")
    public Map<String, Object> addWagonPlease(@RequestBody(required = false) Map<String, Object> tmstrainPleaseApproveResult) {
        return tmsTrainFeign.addWagonPlease(tmstrainPleaseApproveResult);
    }

    @ApiOperation(value = "修改请车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainPleaseApproveResult", value = "请车作业实绩对象", required = false, dataType = "TmstrainPleaseApproveResult"),
    })
    @PostMapping("/updateWagonPlease")
    public Map<String, Object> updateWagonPlease(@RequestBody(required = false) Map<String, Object> tmstrainPleaseApproveResult) {
        return tmsTrainFeign.updateWagonPlease(tmstrainPleaseApproveResult);
    }

    @ApiOperation(value = "逻辑删除请车作业 设置状态码为 3")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainPleaseApproveResult", value = "请车作业实绩对象", required = false, dataType = "TmstrainPleaseApproveResult"),
    })
    @PostMapping("/deleteWagonPlease/{resultId}")
    public Map<String, Object> deleteWagonPlease(@PathVariable("resultId") Integer resultId) {
        return tmsTrainFeign.deleteWagonPlease(resultId);
    }

    @ApiOperation(value = "下发请车作业 设置状态码为 1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "请车作业实绩对象", required = false, dataType = "Integer"),
    })
    @PostMapping("/sendWagonPlease/{resultId}")
    public Map<String, Object> sendWagonPlease(@PathVariable("resultId") Integer resultId) {
        return tmsTrainFeign.sendWagonPlease(resultId);
    }

    //下拉框

    @ApiOperation(value = "查询所有发货单位")
    @GetMapping("/getShipper")
    public Map<String, Object> getShipper() {
        return tmsTrainFeign.getShipper();
    }

    @ApiOperation(value = "查询批车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(70)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getApproveAllWagonPlease")
    public Map<String, Object> getApproveAllWagonPlease(@RequestBody(required = false) Map<String, Object> mapValue,
                                                        Integer apiId,
                                                        Integer pageNum,
                                                        Integer pageSize,
                                                        Integer resultType,
                                                        Integer status,
                                                        String con) {
        return tmsTrainFeign.getApproveAllWagonPlease(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, resultType,status,con);
    }

    @ApiOperation(value = "通过Id查询批车作业")
    @PostMapping("/getApproveWagonPleaseById/{resultId}")
    public Map<String, Object> getApproveWagonPleaseById(@PathVariable("resultId") Integer resultId) {
        return tmsTrainFeign.getApproveWagonPleaseById(resultId);
    }

    @ApiOperation(value = "新增批车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainPleaseApproveResult", value = "请车作业实绩对象", required = false, dataType = "TmstrainPleaseApproveResult"),
    })
    @PostMapping("/addApproveWagonPlease")
    public Map<String, Object> addApproveWagonPlease(@RequestBody(required = false) Map<String, Object> tmstrainPleaseApproveResult) {
        return tmsTrainFeign.addApproveWagonPlease(tmstrainPleaseApproveResult);
    }

    @ApiOperation(value = "修改批车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstrainPleaseApproveResult", value = "请车作业实绩对象", required = false, dataType = "TmstrainPleaseApproveResult"),
    })
    @PostMapping("/updateApproveWagonPlease")
    public Map<String, Object> updateApproveWagonPlease(@RequestBody(required = false) Map<String, Object> tmstrainPleaseApproveResult) {
        return tmsTrainFeign.updateApproveWagonPlease(tmstrainPleaseApproveResult);
    }

    @ApiOperation(value = "逻辑删除批车作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "请车作业实绩对象", required = false, dataType = "Integer"),
    })
    @PostMapping("/deleteApproveWagonPlease/{resultId}")
    public Map<String, Object> deleteApproveWagonPlease(@PathVariable("resultId") Integer resultId) {
        return tmsTrainFeign.deleteApproveWagonPlease(resultId);
    }


    /*======================================汽运==========================================*/


    //******************************************TmstruckLoadResultController***********************************

    @ApiOperation(value="查询所有正在排队的销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(227)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSaleOrderOnQueue")
    public Map<String, Object> getSaleOrderOnQueue(@RequestBody(required=false) Map<String,Object> mapValue,
                                             Integer apiId,
                                             Integer pageNum,
                                             Integer pageSize,
                                             String con){
        return tmsTruckFeign.getSaleOrderOnQueue(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, con);
    }

    @ApiOperation(value="查询订单下的物资")
    @GetMapping("getOrderMaterial/{orderId}")
    public Map<String, Object> getOrderMaterial(@PathVariable("orderId") Integer orderId){
        return tmsTruckFeign.getOrderMaterial(orderId);
    }

    @ApiOperation(value="查询仓库下所有月台")
    @GetMapping("getPlatformIdByWarehouse/{warehouseId}")
    public Map<String, Object> getPlatformIdByWarehouse(@PathVariable("warehouseId") Integer warehouseId){
        return tmsTruckFeign.getPlatformIdByWarehouse(warehouseId);
    }

    @ApiOperation(value="修改装车点和装车顺序：销售钢材专用 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/updateLoadingIdAndLoadSq")
    public Map<String, Object> updateLoadingIdAndLoadSq(@RequestBody(required=false) Map<String, Object> map){
        return tmsTruckFeign.updateLoadingIdAndLoadSq(map);
    }

    @ApiOperation(value = "查询所有装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(91)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllLoadResult")
    public Map<String, Object> getAllLoadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer status,
                                          Integer orderType,
                                          String con,
                                          String userId,
                                          String userIds,
                                                String startTime,String endTime){
        return tmsTruckFeign.getAllLoadResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, status, orderType, con,userId,userIds,startTime,endTime);
    }

    @ApiOperation(value = "新增采购汽车装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/addCGLoadResult")
    public Map<String, Object> addCGLoadResult(@RequestBody(required = false) Map<String, Object> mapValue) {
        return tmsTruckFeign.addCGLoadResult(mapValue);
    }

    @ApiOperation(value="销售新增钢材装车实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("addSaleLoadResult")
    public Map<String, Object> addSaleLoadResult(@RequestBody(required=false) Map<String, Object> map){
        return tmsTruckFeign.addSaleLoadResult(map);
    }

    @ApiOperation(value="销售新增钢渣、水渣、危化品装车实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/addSale2LoadResult")
    public Map<String, Object> addSale2LoadResult(@RequestBody(required=false) Map<String, Object> map){
        return tmsTruckFeign.addSale2LoadResult(map);
    }

    @ApiOperation(value = "修改汽车装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstruckLoadResult", value = "装车作业实绩对象", required = false, dataType = "TmstruckLoadResult"),
    })
    @PostMapping("/updateLoadResult")
    public Map<String, Object> updateLoadResult(@RequestBody Map<String, Object> map) {
        return tmsTruckFeign.updateLoadResult(map);
    }

    @ApiOperation(value = "通过ID查询装车实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLoadResultById/{resultId}")
    public Map<String, Object> getLoadResultById(@PathVariable("resultId") Integer resultId) {
        return tmsTruckFeign.getLoadResultById(resultId);
    }

    @ApiOperation(value = "逻辑删除车装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tmstruckLoadResult", value = "装车作业实绩对象", required = false, dataType = "TmstruckLoadResult"),
    })
    @PostMapping("/deleteLoadResult/{resultId}")
    public Map<String, Object> deleteLoadResult(@PathVariable("resultId") Integer resultId) {
        return tmsTruckFeign.deleteLoadResult(resultId);
    }

    //***************************************TmstruckEnfactoryResultController***************************

    @ApiOperation(value = "查询所有的进厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(220)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllEnFactoryResult")
    public Map<String, Object> getAllEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer orderType,
                                               String startTime,
                                               String endTime,
                                               String userId,
                                               String userIds
    ){
        return tmsTruckFeign.getAllEnFactoryResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, orderType, startTime,endTime,userId,userIds);
    }

    @ApiOperation(value="通过运输订单id查询物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单id", required = false, dataType = "Integer"),
    })
    @GetMapping("/getMaterial")
    public Map<String, Object> getMaterial(Integer orderId){
        return tmsTruckFeign.getMaterial(orderId);
    }

    @ApiOperation(value="通过采集系统传来的数据新增进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/addEnFactoryResult")
    public Map<String, Object> addEnFactoryResult(@RequestBody(required = false) Map<String, Object> mapValue) {
        return tmsTruckFeign.addEnFactoryResult(mapValue);
    }

    @ApiOperation(value = "PDA扫描更新进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/enFactoryResultByPDA")
    public Callable<Map<String, Object>> enFactoryResultByPDA(@RequestBody(required = false) Map<String, Object> mapValue) {
        //PDA扫码会多个反斜杠所以需要截取
        return ()->{
                String orderNumber = (String) mapValue.get("orderNumber");
                orderNumber = orderNumber.substring(0, orderNumber.length()-1);
                mapValue.put("orderNumber", orderNumber);
                return tmsTruckFeign.enFactoryResultByPDA(mapValue);
        };

    }

    //***************************************TmstruckWeightResultController***************************
    @ApiOperation(value = "查询计毛实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(102)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllJiMaoResult")
    public Map<String, Object> getAllJiMaoResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                 Integer apiId,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer orderType,
                                                 String con,
                                                 String userId,
                                                 String userIds,
                                                 String startTime,
                                                 String endTime){
        return tmsTruckFeign.getAllJiMaoResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, orderType, con,userId,userIds,startTime,endTime);
    }

    @ApiOperation(value = "查询计皮实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(104)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllJiPiResult")
    public Map<String, Object> getAllJiPiResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                Integer apiId,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer orderType,
                                                String con,
                                                String userId,
                                                String userIds,
                                                String startTime,
                                                String endTime) {
        return tmsTruckFeign.getAllJiPiResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, orderType, con,userId,userIds,startTime,endTime);
    }


    @ApiOperation(value = "采集新增计毛实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "采集的数据", required = false, dataType = "Map"),
    })
    @PostMapping("/addJiMaoResult")
    public Map<String, Object> addJiMaoResult(@RequestBody Map<String, Object> mapValue) {
        return tmsTruckFeign.addJiMaoResult(mapValue);
    }

    @ApiOperation(value = "采集新增计皮实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "采集的数据", required = false, dataType = "Map"),
    })
    @PostMapping("/addJiPiResult")
    public Map<String, Object> addJiPiResult(@RequestBody Map<String, Object> mapValue) {
        return tmsTruckFeign.addJiPiResult(mapValue);
    }

    //****************************************TmstruckUnloadResultController*******************************

    @ApiOperation(value = "查询卸货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(103)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getUnloadResult")
    public Map<String, Object> getUnloadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer orderType,
                                               String con,
                                               String userId,
                                               String userIds,
                                               String startTime,
                                               String endTime
    ){
        return tmsTruckFeign.getUnloadResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, orderType, con,userId,userIds,startTime,endTime);
    }

    @ApiOperation(value = "添加卸货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/addUnloadResult")
    public Map<String, Object> addUnloadResult(@RequestBody Map<String, Object> mapValue) {
        return tmsTruckFeign.addUnloadResult(mapValue);
    }

    @ApiOperation(value = "更新卸货实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/updateUnloadResult")
    public Map<String, Object> updateUnloadResult(@RequestBody Map<String, Object> mapValue) {
        return tmsTruckFeign.updateUnloadResult(mapValue);
    }
    //****************************************TmstruckReceiptResultController*******************************


    @ApiOperation(value = "查询收货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(107)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getReceiveResult")
    public Map<String, Object> getReceiveResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                                Integer orderType,String con,
                                                String startTime,
                                                String endTime
    ){
        return tmsTruckFeign.getReceiveResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, orderType, con,startTime,endTime);
    }


    //****************************************TmstruckLeaveFactoryResultController*******************************


    @ApiOperation(value="查询出厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(110)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLeaveFactoryResult")
    public Map<String, Object> getLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer orderType,
                                                     String con,
                                                     String carrierSsoId,
                                                     String userId,
                                                     String userIds,
                                                     String startTime,
                                                     String endTime
    ){
        return tmsTruckFeign.getLeaveFactoryResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, orderType, con, carrierSsoId,userId,userIds,startTime,endTime);
    }


    @ApiOperation(value="PAD扫描汽车出厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/addLeaveFactoryResult")
    public Map<String, Object> addLeaveFactoryResult(@RequestBody(required = false) Map<String, Object> mapValue) {
        return tmsTruckFeign.addLeaveFactoryResult(mapValue);
    }

    //****************************************TmstruckMeasureCommissionController*******************************

    @ApiOperation(value = "查询计量委托 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllMeasureCommission/{type}")
    public Map<String, Object> getAllMeasureCommission(@PathVariable("type") Integer type) {
        return tmsTruckFeign.getAllMeasureCommission(type);
    }

    //****************************************TmstruckQualityResultController*******************************

    @ApiOperation(value = "查询所有的质检作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(111)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQualityResult")
    public Map<String, Object> getQualityResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                Integer apiId,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer orderType,
                                                String con,
                                                String startTime,
                                                String endTime
    ){
        return tmsTruckFeign.getQualityResult(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize,orderType, con,startTime,endTime);
    }

    @ApiOperation(value = "通过ID获取质检实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "质检作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQualityResultById/{resultId}")
    public Map<String, Object> getQualityResultById(@PathVariable("resultId") Integer resultId) {
        return tmsTruckFeign.getQualityResultById(resultId);
    }

    @ApiOperation(value = "修改质检实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "质检作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/updateQualityResult")
    public Map<String, Object> updateQualityResult(@RequestBody(required = false) Map<String, Object> mapValue) {
        return tmsTruckFeign.updateQualityResult(mapValue);
    }

    //*********************************内转物流tms-train*********************************************************************
    @PostMapping("/addTrainLoadResultForConverted")
    @ApiOperation(value = "内转物流新增装车")
    public Map<String, Object> addTrainLoadResultForConverted(@RequestBody(required = false) Map<String, Object> tmstrainLoadingResult) {
        return tmsTrainFeign.addTrainLoadResultForConverted(tmstrainLoadingResult);
    }

    @ApiOperation(value = "内转新增卸车实绩")
    @ApiImplicitParams({
    })
    @PostMapping(value = "/addTmsTrainUnloadResultForNZ")
    public Map<String, Object> addTmsTrainUnloadResultForNZ(@RequestBody(required = false)Map<String, Object> map) {
        return tmsTrainFeign.addTmsTrainUnloadResultForNZ(map);
    }

    @ApiOperation(value = "查询车皮物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(213)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/getMaterialAndCarByLoadingId")
    public Map<String, Object> getMaterialAndCarByLoadingId(
            @RequestBody(required = false) Map<String, Object> mapValue,
            Integer apiId,
            Integer pageNum,
            Integer pageSize,
            Integer loadingId,
            Integer unloadingId) {
        return tmsTrainFeign.getMaterialAndCarByLoadingId(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, loadingId, unloadingId);
    }

    @PostMapping("/selectLoadByResultId/{resultId}")
    @ApiOperation(value = "内转物流通过主键查询车皮装车作业信息")
    public Map<String, Object> selectLoadByResultId(@PathVariable("resultId") BigDecimal resultId) {
        Map<String, Object> mes = tmsTrainFeign.selectLoadByResultId(resultId);
        return mes;
    }

    @ApiOperation(value = "内转查询装车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(203)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getTmstrainWagonLoadForConverted")
    public Map<String, Object> getTmstrainWagonLoadForConverted(@RequestBody(required = false)
                                                                        Integer apiId,
                                                                Integer pageNum,
                                                                Integer pageSize,
                                                                String con
    ) {
        return tmsTrainFeign.getTmstrainWagonLoadForConverted(apiId, pageNum, pageSize,con);
    }




    @ApiOperation(value = "查询进口矿未绑定装车实绩的车皮")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(203)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getResultType")
    public Map<String, Object> getResultType(@RequestBody(required = false)Map<String,Object> map,
                                                                        Integer apiId,

                                                                String con
    ) {
        return tmsTrainFeign.getResultType(map == null ? new HashMap<>() : map,apiId,con);
    }

    @PostMapping("/addShipLoadResult")
    @ApiOperation(value = "江港-达州新增装车")
    public Map<String, Object> addShipLoadResult(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTrainFeign.addShipLoadResult(map);
    }


    @PostMapping("/addWagonPleaseForNZ")
    @ApiOperation(value = "内转物流新增请车")
    public Map<String, Object> addPleaseForNZ(@RequestBody(required = false) Map<String, Object> tmstrainLoadingResult) {
        return tmsTrainFeign.addPleaseForNZ(tmstrainLoadingResult);
    }

    @ApiOperation(value="内转新增达州站-厂内装车实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "", required = false, dataType = "Map"),
    })
        @PostMapping("/addDaZhouToDaGangLoadResult")
    public Map<String, Object> addDaZhouToDaGangLoadResult(@RequestBody(required = false)Map<String, Object> map){
        return tmsTruckFeign.addDaZhouToDaGangLoadResult(map);
    }

    @ApiOperation(value = "内转查询请车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(199)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllWagonPleaseForConverted")
    public Map<String, Object> getAllWagonPleaseForConverted(@RequestBody(required = false) Map<String, Object> mapValue,
                                                             Integer apiId,
                                                             Integer pageNum,
                                                             Integer pageSize,
                                                             Integer status,
                                                             String con
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        mapValue.put("status", status);
        return tmsTrainFeign.getTmstrainWagonLoadForConverted(apiId, pageNum, pageSize,con);
    }

    @PostMapping("/getPleasePlanByResultId/{resultId}")
    @ApiOperation(value = "内转物流通过主键查请车计划")
    public Map<String, Object> getPleasePlanByResultId(@PathVariable("resultId") BigDecimal resultId) {
        Map<String, Object> mes = tmsTrainFeign.getPleasePlanByResultId(resultId);
        return mes;
    }

    @PostMapping("/getApproveByResultId/{resultId}")
    @ApiOperation(value = "内转物流通过主键查询车皮请车作业信息")
    public Map<String, Object> getApproveByResultId(@PathVariable("resultId") BigDecimal resultId) {
        Map<String, Object> mes = tmsTrainFeign.getApproveByResultId(resultId);
        return mes;
    }

    @ApiOperation(value = "查询卸车作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(201)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),

    })
    @PostMapping("/selectWagonUnLoadResultForConverted")
    public Map<String, Object> selectWagonUnLoadResultForConverted(@RequestBody(required = false) Map<String, Object> mapValue,
                                                                   Integer apiId,
                                                                   Integer pageNum,
                                                                   Integer pageSize,
                                                                   String con
    ) {
        return tmsTrainFeign.selectWagonUnLoadResultForConverted(apiId, pageNum, pageSize,con);
    }

    @ApiOperation(value = "内转查询火车卸货信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(202)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),

    })
    @PostMapping("/selectTrainUnLoadResultForConverted")
    public Map<String, Object> selectTrainUnLoadResultForConverted(@RequestBody(required = false) Map<String, Object> mapValue,
                                                                   Integer apiId,
                                                                   Integer pageNum,
                                                                   Integer pageSize,
                                                                   String con
    ) {
        return tmsTrainFeign.selectTrainUnLoadResultForConverted(apiId, pageNum, pageSize,con);
    }

    /**
     * 新增汽车装货实绩
     */
    @ApiOperation(value = "新增汽车装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/addLoadResultForConverted")
    public Map<String, Object> addLoadResultForConverted(@RequestBody(required = false) Map<String, Object> map) {
        Map<String, Object> resTfulResult = tmsTruckFeign.addLoadResultForConverted(map);
        return resTfulResult;
    }

    @ApiOperation(value = "查询所有装车实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(91)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectLoadResultForConverted")
    public Map<String, Object> selectLoadResultForConverted(@RequestBody(required = false) Map<String, Object> mapValue,
                                                            Integer apiId,
                                                            Integer pageNum,
                                                            Integer pageSize
    ) {
        return tmsTruckFeign.selectLoadResultForConverted(mapValue, apiId, pageNum, pageSize);
    }

    //根据实绩id渲染数据
    @ApiOperation(value = "通过ID查询装车实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/getLoadResultByResultId/{resultId}")
    public Map<String, Object> getLoadResultByResultId(@PathVariable("resultId") Integer resultId) {
        Map<String, Object> resTfulResult = tmsTruckFeign.getLoadResultByResultId(resultId);
        return resTfulResult;
    }

    @ApiOperation(value = "内转物流查询质检作业")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(204)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectQualityResultForConverted")
    public Map<String, Object> selectQualityResultForConverted(@RequestBody(required = false) Map<String, Object> mapValue,
                                                               Integer apiId,
                                                               Integer pageNum,
                                                               Integer pageSize
    ) {
        return tmsTruckFeign.selectQualityResultForConverted(mapValue, apiId, pageNum, pageSize);
    }

    /**
     * 展示计数实绩列表
     */

    @ApiOperation(value = "查询计数实绩列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(364)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectCountList")
    public Map<String, Object> selectCountList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize
    ) {
        return tmsTruckFeign.selectCountList(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize);
    }

    //采购内转待装车实绩
    @ApiOperation(value = "查询待装车运单列表")
    @PostMapping("/cgNzLoadingResult")
    public Map<String, Object> cgNzLoadingResult(@RequestBody(required = false) Map<String, Object> mapVal,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer orderType,
                                               Integer orderStatus
    ) {
        return tmsTruckFeign.cgNzLoadingResult(mapVal==null?new HashMap<>():mapVal, apiId, pageNum, pageSize,orderType,orderStatus);
    }



    /**
     * 内转物流卸货装车实绩
     *
     * @param map
     * @return
     */
    @ApiOperation(value = "内转物流新增卸货实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/addUnLoadResultForconverted")
    public Map<String, Object> addUnLoadResultForconverted(@RequestBody(required = false) Map<String, Object> map) {
        Map<String, Object> resTfulResult = tmsTruckFeign.addUnLoadResultForconverted(map);
        return resTfulResult;
    }

    @ApiOperation(value = "查询所有的包月作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(还没有)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getTmstruckMonthResult")
    public Map<String, Object> getTmstruckMonthResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                                      Integer apiId,
                                                      Integer pageNum,
                                                      Integer pageSize
    ) {
        return tmsTruckFeign.getTmstruckMonthResult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize);
    }

    /**
     * 通过运输订单判断下一步是否需要计量,更新汽车衡到计量实绩中
     */
    @PostMapping("/updateTruckCalculate/{orderId}")
    public Map<String, Object> updateTruckCalculate(@PathVariable("orderId") Integer orderId) {
        return tmsTruckFeign.isNextNeedJl(orderId);
    }

    @ApiOperation(value="查询所有的短信实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(175)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSmsResult")
    public Map<String, Object> getSmsResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            String con
    ){
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return tmsTruckFeign.getSmsResult(mapValue,apiId,pageNum,pageSize,con);
    }

    @ApiOperation(value="APP查询进厂实绩")
    @PostMapping("/getEnfactoryResultList")
    public Map<String ,Object> getEnfactoryResultList() {
        return tmsTruckFeign.getEnfactoryResultList();
    }

    @ApiOperation(value="APP通过运输订单id查询进厂实绩")
    @PostMapping("/getEnfactoryMessageByOrderId")
    public Map<String ,Object> getEnfactoryMessageByOrderId(String orderNumber) {
        return tmsTruckFeign.getEnfactoryMessageByOrderId(orderNumber);
    }

    @ApiOperation(value="查询计皮实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(363)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllTimeTaskResult")
    public RESTfulResult getAllTimeTaskResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              String con,
                                              String  userId,
                                              String startTime,
                                              String endTime,
                                              Integer orderType
    ){
        return tmsTruckFeign.getAllTimeTaskResult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, con,userId,startTime,endTime,orderType);
    }

    @ApiOperation(value="查询倒库实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(516)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllReverseResult")
    public RESTfulResult getAllReverseResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              String con,
                                              String  userId,
                                              String startTime,
                                              String endTime){
        return tmsTruckFeign.getAllReverseResult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, con,userId,startTime,endTime);
    }

    @ApiOperation(value="新增钢材到异地库达州站驻港人员确定收货")
    @PostMapping("/addSteelNzReceiptResult")
    public Map<String, Object> addSteelNzReceiptResult(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTruckFeign.addSteelNzReceiptResult(map);
    }


    @ApiOperation(value="更新计量实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapList", value = "计量数据", required = false, dataType = "List<Map>"),
    })
    @PostMapping("/updateTruckWeight")
    public Map<String, Object> updateTruckWeight(@RequestBody List<Map<String, Object>> mapList){
        return tmsTruckFeign.updateTruckWeight(mapList);
    }

    @ApiOperation(value="查询所有的退货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId()", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllReturnResult")
    public Map<String, Object> getAllReturnResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer orderType,
                                            String con
    ){
        return tmsTruckFeign.getAllReturnResult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, orderType, con);
    }
    @ApiOperation(value="提货单 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/getBillOrder")
    public Map<String, Object> getBillOrder(@RequestParam String orderNumber){
        return tmsTruckFeign.getBillOrder(orderNumber);
    }

    @ApiOperation(value="发货通知单 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/getDeliveryOrder")
    public Map<String, Object> getDeliveryOrder(@RequestParam String orderNumber){
        return tmsTruckFeign.getDeliveryOrder(orderNumber);
    }
    @ApiOperation(value="模糊查询江船名 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "state", value = "用户输入的江船名", required = false, dataType = "String"),
    })
    @PostMapping("getShipNameList")
    public Map<String, Object> getShipNameList(@RequestParam(value = "state") String state){
        return tmsshipFeign.getShipNameList(state);
    }

    @ApiOperation(value = "国产矿导入")
    @PostMapping(value = "/importDomesticLoadResult")
    public Map<String, Object> importDomesticLoadResult(@RequestBody(required = false) Map<String, Object> mapValue) {
        return tmsTrainFeign.importDomesticLoadResult(mapValue);
    }

    @ApiOperation(value = "进口矿导入")
    @PostMapping(value = "/importImportedLoadResult")
    public Map<String, Object> importImportedLoadResult(@RequestBody(required = false) Map<String, Object> mapValue) {
        return tmsTrainFeign.importImportedLoadResult(mapValue);
    }


    @ApiOperation(value = "国产矿新增/海港-老区轨道衡新增装车")
    @PostMapping(value = "/addDomesticLoadResult")
    public Map<String, Object> addDomesticLoadResult(@RequestBody(required = false) Map<String, Object> mapValue) {
        return tmsTrainFeign.addDomesticLoadResult(mapValue);
    }

    @ApiOperation(value = "国产矿物流补录装车信息")
    @PostMapping(value = "/updateDomesticLoadResult")
    public Map<String, Object> updateDomesticLoadResult(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTrainFeign.updateDomesticLoadResult(map);
    }

    @ApiOperation(value = "添加火车计量委托")
    @PostMapping(value = "/addTrainMeasureCommission")
    public Map<String, Object> addTrainMeasureCommission(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTrainFeign.addTrainMeasureCommission(map);
    }

    @ApiOperation(value = "查询需要发送计量委托的车皮信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(209)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/getLoadResultToSendMC")
    public Map<String, Object> getLoadResultToSendMC( @RequestBody(required = false) Map<String, Object> mapValue,
            Integer apiId,
            Integer pageNum,
            Integer pageSize, String startTime, String endTime,Integer resultType,String con) {
        return tmsTrainFeign.getLoadResultToSendMC(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, resultType,startTime,endTime,con);
    }

    @ApiOperation(value = "查询计量数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(209)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/getWeightResult")
    public Map<String, Object> getWeightResult( @RequestBody(required = false) Map<String, Object> mapValue,
                                                      Integer apiId,
                                                      Integer pageNum,
                                                      Integer pageSize,String startTime, String endTime,Integer resultType,String con) {
        return tmsTrainFeign.getWeightResult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, resultType,startTime,endTime,con);
    }

    @ApiOperation(value = "批量新增计量委托")
    @PostMapping(value = "/batchSendMeasureCommission")
    public Map<String, Object> batchSendMeasureCommission(@RequestBody(required = false) Map<String, Object> map) {
        return tmsTrainFeign.batchSendMeasureCommission(map);
    }


      //获取合同水分值，实装吨位，水分吨位
    @PostMapping("/getMoistureAndInstallations")
    public Map<String,Object> getMoistureAndInstallations(@RequestBody(required=false) Map<String,Object> map){
        return tmsshipFeign.getMoistureAndInstallations(map);
    }


    @ApiOperation(value="查询辅料燃料统计报表")
    @PostMapping("/getRLFLReport")
    public Map<String, Object> getRLFLReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String startTime,
                                               String endTime,
                                               Integer orderType,
                                               String con
    ){
        return tmsTruckFeign.getRLFLReport(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, startTime, endTime,  orderType,con);
    }
    @ApiOperation(value="查询销售统计报表")
    @PostMapping("/getAllSaleReport")
    public Map<String, Object> getAllSaleReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId,
                                                Integer orderType,
                                                Integer shipperId,
                                                String receiveName,
                                                String materialName,
                                                String wareHouse
    ){
        return tmsTruckFeign.getAllSaleReport(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, startTime, endTime, carrierSsoId,orderType,shipperId,receiveName,materialName,wareHouse);
    }

    @ApiOperation(value="查询销售统计报表筛选过后的总净重")
    @PostMapping("/getAllSaleReportTotal")
    public Map<String, Object> getAllSaleReportTotal(@RequestBody(required=false) Map<String,Object> mapValue,
                                                String startTime, String endTime,
                                                String carrierSsoId
    ){
        return tmsTruckFeign.getAllSaleReportTotal(mapValue==null?new HashMap<>():mapValue, startTime, endTime, carrierSsoId);
    }

    @ApiOperation(value="查询零星物资进厂统计报表")
    @PostMapping("/getSporadicSuppliesReport1")
    public Map<String, Object> getSporadicSuppliesReport1(@RequestBody(required=false) Map<String,Object> mapValue,
                                                Integer apiId,
                                                Integer pageNum,
                                                Integer pageSize,
                                                String startTime, String endTime,
                                                String carrierSsoId,
                                               String userId,
                                               String userIds,
                                               String con,
                                               Integer orderType
    ){
        return tmsTruckFeign.getSporadicSuppliesReport1(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,startTime, endTime, carrierSsoId,userId,userIds,con,orderType);
    }
    @ApiOperation(value="查询零星物资出厂统计报表")
    @PostMapping("/getSporadicSuppliesReport2")
    public Map<String, Object> getSporadicSuppliesReport2(@RequestBody(required=false) Map<String,Object> mapValue,
                                                          Integer apiId,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          String startTime,
                                                          String endTime,
                                                          String carrierSsoId,
                                                          String userId,
                                                          String userIds,
                                                          String con,
                                                          Integer orderType
    ){
        return tmsTruckFeign.getSporadicSuppliesReport2(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, startTime, endTime, carrierSsoId,userId,userIds,con,orderType);
    }

    @ApiOperation(value="查询采购内转运输实绩")
    @PostMapping("/getPurInwardReport")
    public Map<String, Object> getPurInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                                          Integer apiId,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          String startTime,
                                                          String endTime) {
        return tmsTruckFeign.getPurInwardReport(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, startTime, endTime);
    }
    @ApiOperation(value="查询内转运输实绩")
    @PostMapping("/getInwardReport")
    public Map<String, Object> getInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                                          Integer apiId,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          String startTime,
                                                          String endTime) {
        return tmsTruckFeign.getInwardReport(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, startTime, endTime);
    }
    @ApiOperation(value="")
    @PostMapping("/getLoaderForResultDetail")
    public Map<String, Object> getLoaderForResultDetail(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String startTime,
                                               String endTime,
                                               String con, String isPage) {
        return tmsTruckFeign.getLoaderForResultDetail(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, startTime, endTime,con,isPage);
    }


    @ApiOperation(value="获取内转报表")
    @PostMapping("/getPurchaseInwardList")
    public Map<String, Object> getPurchaseInwardList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                        Integer apiId,
                                                        Integer pageNum,
                                                        Integer pageSize,
                                                        String startTime,
                                                        String endTime,
                                                        String orgCode,
                                                        String isPage,
                                                        String index) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        return tmsTruckFeign.getPurchaseInwardList(mapValue,apiId,pageNum,pageSize,startTime,endTime,orgCode,isPage,index);
    }





    @ApiOperation(value="获取采购订单报表")
    @PostMapping("/getPurchaseOrderList")
    public Map<String, Object> getPurchaseOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                             Integer apiId,
                                             Integer pageNum,
                                             Integer pageSize,
                                             String startTime,
                                             String endTime,
                                             String orgCode,
                                                    String isPage,
                                                    String index) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        return tmsTruckFeign.getPurchaseOrderList(mapValue,apiId,pageNum,pageSize,startTime,endTime,orgCode,isPage,index);
    }



    @ApiOperation(value="获取采购订单报表")
    @PostMapping("/getInwardInFactory")
    public Map<String, Object> getInwardInFactory(@RequestBody(required=false) Map<String,Object> mapValue,
                                                    Integer apiId,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    String startTime,
                                                    String endTime,
                                                    String orgCode,
                                                    String isPage,
                                                  String index) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        return tmsTruckFeign.getInwardInFactory(mapValue,apiId,pageNum,pageSize,startTime,endTime,orgCode,isPage,index);
    }



    @ApiOperation(value="获取销售订单列表")
    @PostMapping("/getSaleOrderList")
    public Map<String, Object> getSaleOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                    Integer apiId,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    String startTime,
                                                    String endTime,
                                                    String orgCode,
                                                    String isPage,
                                                   String index) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        return tmsTruckFeign.getSaleOrderList(mapValue,apiId,pageNum,pageSize,startTime,endTime,orgCode,isPage,index);
    }


    @PostMapping("/sendMeasureCommission")
    public Map<String, Object> sendMeasureCommission(@RequestBody(required = false) Map<String, Object> map){
        return  tmsTruckFeign.sendMeasureCommission(map);
    }

    @ApiOperation(value="发送留皮计量委托(neizhuan)")
    @GetMapping("/sendLiuPiMeasureCommission")
    public Map<String, Object> sendLiuPiMeasureCommission(String capacityNumber){
        return tmsTruckFeign.sendLiuPiMeasureCommission(capacityNumber);
    }


    @ApiOperation(value="新增计时作业实绩")
    @PostMapping("/addTimeTaskResult")
    public Map<String, Object> addTimeTaskResult(@RequestBody(required = false) Map<String, Object> map){
        return  tmsTruckFeign.addTimeTaskResult(map);
    }

    @ApiOperation(value="计时判断是否开始")
    @PostMapping("/JudgeTimeTask")
    public Map<String, Object> JudgeTimeTask(@RequestBody(required = false) Map<String, Object> map){
        return  tmsTruckFeign.JudgeTimeTask(map);
    }



    @ApiOperation(value="计时暂停")
    @PostMapping("/unitSureEndTimeout")
    public Map<String, Object> unitSureEndTimeout(@RequestBody(required = false) Map<String, Object> map){
        return  tmsTruckFeign.unitSureEndTimeout(map);
    }

    @ApiOperation(value="计时暂停")
    @PostMapping("/JudgeTimeTaskPause")
    public Map<String, Object> JudgeTimeTaskPause(@RequestBody(required = false) Map<String, Object> map){
        return  tmsTruckFeign.JudgeTimeTaskPause(map);
    }


    @ApiOperation(value="对内转车辆装货点进行统计")
    @PostMapping("/getLoading")
    public Map<String, Object> getLoading(@RequestBody(required=false) Map<String,Object> mapValue,
                                             Integer apiId,
                                             Integer pageNum,
                                             Integer pageSize,
                                             String startTime,
                                             String endTime
    ){
        return tmsTruckFeign.getLoading(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, startTime, endTime);
    }


    @ApiOperation(value="对内转车辆装货点进行统计")
    @PostMapping("/getLoaderResult")
    public Map<String, Object> getLoaderResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime
    ){
        return tmsTruckFeign.getLoaderResult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, startTime, endTime);
    }





    @ApiOperation(value="对内转车辆装卸货点进行统计")
    @PostMapping("/getUnLoading")
    public Map<String, Object> getUnLoading(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime
    ){
        return tmsTruckFeign.getUnLoading(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, startTime, endTime);
    }







    @ApiOperation(value="查询零星中转统计报表")
    @PostMapping("/getLXInwardReport")
    public Map<String, Object> getLXInwardReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize,
                                           String startTime,
                                           String endTime,
                                                 String con
    ){
        return tmsTruckFeign.getLXInwardReport(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, startTime, endTime,con);
    }


    @ApiOperation(value="拼装车内转统计报表")
    @PostMapping("/getInwardReportForAssemble")
    public Map<String, Object> getInwardReportForAssemble(@RequestBody(required=false) Map<String,Object> mapValue,
                                                 Integer apiId,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 String startTime,
                                                 String endTime,BigDecimal orderType, String index, String isPage,String orgCode

    ){
        return tmsTruckFeign.getInwardReportForAssemble(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, startTime, endTime,orderType,index,isPage,orgCode);
    }


    @ApiOperation("保卫部随机抽查车牌号")
    @PostMapping("/getCapacityByDefend")
    public Map<String,Object> getCapacityByDefend(@RequestBody(required = false) Map<String,Object> mapValue,
                                                  Integer apiId,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  String startTime,
                                                  String endTime,
                                                  String con,
                                                  String yes){
        return tmsTruckFeign.getCapacityByDefend(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,startTime,endTime,con,yes);
    }

    @ApiOperation("厂外抵达作业")
    @PostMapping("/getReceiptResult")
    public Map<String,Object> getReceiptResult(@RequestBody(required = false) Map<String,Object> mapValue,
                                                  Integer apiId,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  String con,
                                                  String startTime,
                                                  String endTime){
        return tmsTruckFeign.getReceiptResult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,con,startTime,endTime);
    }

    @ApiOperation("展示满货箱的照片")
    @PostMapping("/getReceiptPhoto")
    public String getReceiptPhoto(@RequestParam String orderNumber){
        return tmsTruckFeign.getReceiptPhoto(orderNumber);
    }


    @ApiOperation("厂外收货作业")
    @PostMapping("/getReceivingResult")
    public Map<String,Object> getReceivingResult(@RequestBody(required = false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String con,
                                               String startTime,
                                               String endTime){
        return tmsTruckFeign.getReceivingResult(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,con,startTime,endTime);
    }

    @ApiOperation("展示收货的照片")
    @PostMapping("/getReceivingPhoto")
    public Map<String,Object> getReceivingPhoto(@RequestParam String orderNumber){
        return tmsTruckFeign.getReceivingPhoto(orderNumber);
    }
    @ApiOperation("展示收货的照片")
    @PostMapping("/getReceivingPhotoByUrl")
    public Map<String,Object> getReceivingPhotoByUrl(@RequestParam String orderNumber) throws Exception {
        Map<String,Object> map=tmsTruckFeign.getReceivingPhotoByUrl(orderNumber);
        if(map.containsKey("resultEmptyContainerPhoto") && map.get("resultEmptyContainerPhoto")!=null){
            String resultEmptyContainerPhoto = (String) imageFileUtils.downloadFile(map.get("resultEmptyContainerPhoto").toString());
            map.put("resultEmptyContainerPhoto",resultEmptyContainerPhoto);
        }
        if(map.containsKey("resultSignedNotePhoto") && map.get("resultSignedNotePhoto")!=null){
            String resultSignedNotePhoto = (String) imageFileUtils.downloadFile(map.get("resultSignedNotePhoto").toString());
            map.put("resultSignedNotePhoto",resultSignedNotePhoto);
        }
        return map;
    }


    @ApiOperation("根据船舶位置查询船舶动态")
    @PostMapping("/getShipLocationStatus")
    public Map<String,Object> getShipLocationStatus(String shipLocation) {
        Map<String, Object> map = tmsshipFeign.getShipLocationStatus(shipLocation);
        return map;
    }
    //根据用户输入提货联系人模糊查询提货联系人、提货人身份证号、联系电话
    @ApiOperation(value="根据用户输入提货联系人模糊查询提货联系人、提货人身份证号、联系电话", notes="模糊查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "personName",value = "用户输入的输入提货联系人", required = false, dataType = "String")
    })

    @PostMapping("/getPersonByName")
    public Map<String,Object>  getPersonByName(@RequestParam(value ="personName")String personName){
        return tmsshipFeign.getPersonByName(personName);

    }

    //根据用户输入提货联系人模糊查询提货联系人、提货人身份证号、联系电话
    @ApiOperation(value="根据发货通知中用户输入提货联系人模糊查询提货联系人、提货人身份证号、联系电话", notes="模糊查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "personName",value = "用户输入的输入提货联系人", required = false, dataType = "String")
    })

    @PostMapping("/getNoticeContactNumberByPerson")
    public Map<String,Object>  getNoticeContactNumberByPerson(@RequestParam(value ="personName")String personName){
        return tmsshipFeign.getNoticeContactNumberByPerson(personName);

    }




    @ApiOperation(value="获取内转报表")
    @PostMapping("/getOutFactoryInwardList")
    public Map<String, Object> getOutFactoryInwardList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     String startTime,
                                                     String endTime,
                                                     String orgCode,
                                                     String isPage,
                                                     String index) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        return tmsTruckFeign.getOutFactoryInwardList(mapValue,apiId,pageNum,pageSize,startTime,endTime,orgCode,isPage,index);
    }
	
	@ApiOperation(value = "根据物资名和外轮船名查询采购订单号")
    @PostMapping(value = "/findPurchaseOrderList")
    public Map<String, Object> findPurchaseOrderList(@RequestBody(required = false) Map<String, Object> map,
                                                          Integer apiId,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          String materialName,
                                                          String resultForeignShipName,
                                                          String supplierName){
        if(map==null)
            map=new HashMap<>();
        System.out.println(map);
        return tmsTrainFeign.getPurchaseOrderList(map,apiId,pageNum,pageSize,materialName, resultForeignShipName,supplierName);
    }

    @ApiOperation(value = "查询待绑定的批次")
    @PostMapping(value = "/findBatchForBind")
    public Map<String, Object> findBatchForBind(@RequestBody(required = false) Map<String, Object> map,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     String materialName,
                                                     String foreignShipName){
        if(map==null)
            map=new HashMap<>();
        return tmsshipFeign.findBatchForBind(map,apiId,pageNum,pageSize,materialName, foreignShipName);
    }

    @ApiOperation(value = "绑定批次")
    @PostMapping(value = "bindBatch")
    Map<String, Object> bindBatch(@RequestBody(required = false) Map<String, Object> map){
        return tmsshipFeign.bindBatch(map);
    }

    @ApiOperation(value = "销售钢材统计报表")
    @PostMapping("/getSaleSteelReport")
    public Map<String,Object> getSaleSteelReport(@RequestBody(required = false)Map<String,Object>map,
                                                 String startTime,
                                                 String endTime,
                                                 String carrierSsoId,
                                                 String receiveName,
                                                 String materialName,
                                                 String specification,
                                                 String remark,
                                                 String capacityNo,
                                                 String carrierName,
                                                 String consigneeName,
                                                 String saler,
                                                 String easPrimaryId){
        if(map==null){
            map=new HashMap<>();
        }
        return tmsTruckFeign.getSaleSteelReport(map,startTime,endTime,carrierSsoId,receiveName,materialName,specification,remark,capacityNo,carrierName,consigneeName,saler,easPrimaryId);
    }

    @ApiOperation(value = "计费详单（未结算）")
    @PostMapping("/getSaleSteelReportNew")
    public Map<String,Object> getSaleSteelReportNew(@RequestBody(required = false)Map<String,Object>map,
                                                 String startTime,
                                                 String endTime,
                                                 String carrierSsoId,
                                                 String receiveName,
                                                 String materialName,
                                                 String specification,
                                                 String remark,
                                                 String capacityNo,
                                                 String carrierName,
                                                 String consigneeName,
                                                 String saler,
                                                 String easPrimaryId){
        if(map==null){
            map=new HashMap<>();
        }
        return tmsTruckFeign.getSaleSteelReportNew(map,startTime,endTime,carrierSsoId,receiveName,materialName,specification,remark,capacityNo,carrierName,consigneeName,saler,easPrimaryId);
    }


    @ApiOperation(value = "计费详单（已结算）")
    @PostMapping("/getSettledSaleSteelReportNew")
    public Map<String,Object> getSettledSaleSteelReportNew(@RequestBody(required = false)Map<String,Object>map,
                                                    String startTime,
                                                    String endTime,
                                                    String carrierSsoId,
                                                    String receiveName,
                                                    String materialName,
                                                    String specification,
                                                    String remark,
                                                    String capacityNo,
                                                    String carrierName,
                                                    String consigneeName,
                                                    String saler,
                                                    String easPrimaryId){
        if(map==null){
            map=new HashMap<>();
        }
        return tmsTruckFeign.getSettledSaleSteelReportNew(map,startTime,endTime,carrierSsoId,receiveName,materialName,specification,remark,capacityNo,carrierName,consigneeName,saler,easPrimaryId);
    }

    @ApiOperation(value = "销售钢材未装统计报表")
    @PostMapping("/loadingSaleSteelReport")
    public Map<String,Object> loadingSaleSteelReport(@RequestBody(required = false)Map<String,Object>map,
                                                 String startTime,
                                                 String endTime,
                                                 String carrierSsoId,
                                                 String receiveName,
                                                 String materialName,
                                                 String specification,
                                                 String remark,
                                                 String capacityNo,
                                                 String carrierName,
                                                 String consigneeName,
                                                 String saler,
                                                 String easPrimaryId){
        if(map==null){
            map=new HashMap<>();
        }
        return tmsTruckFeign.loadingSaleSteelReport(map,startTime,endTime,carrierSsoId,receiveName,materialName,specification,remark,capacityNo,carrierName,consigneeName,saler,easPrimaryId);
    }


    @ApiOperation(value = "销售钢材统计报表")
    @PostMapping("/getInwardSaleSteelReport")
    public Map<String,Object> getInwardSaleSteelReport(@RequestBody(required = false)Map<String,Object>map,
                                                 String startTime,
                                                 String endTime,
                                                 String carrierSsoId,
                                                 String receiveName,
                                                 String materialName,
                                                 String specification,
                                                 String remark,
                                                 String capacityNo,
                                                 String carrierName,
                                                 String consigneeName,
                                                 String saler){
        if(map==null){
            map=new HashMap<>();
        }
        return tmsTruckFeign.getInwardSaleSteelReport(map,startTime,endTime,carrierSsoId,receiveName,materialName,specification,remark,capacityNo,carrierName,consigneeName,saler);
    }

    @ApiOperation(value = "销售钢材派单列表")
    @PostMapping("/getInwardSaleSteelOrder")
    public Map<String,Object> getInwardSaleSteelOrder(@RequestBody(required = false)Map<String,Object>map,
                                                       String startTime,
                                                       String endTime,
                                                       String remark,
                                                       String capacityNo,
                                                       String consigneeName,
                                                       String saler){
        if(map==null){
            map=new HashMap<>();
        }
        return tmsTruckFeign.getInwardSaleSteelOrder(map,startTime,endTime,remark,capacityNo,consigneeName);
    }

    @ApiOperation(value = "发送短信")
    @PostMapping("sendMeaage")
    public Map<String,Object> sendMeaage(@RequestParam String mobile,
                                         @RequestParam String content){
        return tmsTruckFeign.sendMeaage(mobile,content);
    }

    /**
     * 修改三程船装船作业明细
     * @param
     * @return
     */
    @PostMapping("/updateThreeSectionDetails")
    public Map<String,Object> updateThreeSectionDetails(@RequestBody(required = false) Map<String, Object> mapVal){
        if (mapVal == null) {
            mapVal = new HashMap<>();
        }
        return tmsshipFeign.updateThreeSectionDetails(mapVal);
    }

    @PostMapping("/addPleaseResult")
    public Map<String,Object> addPleaseResult(@RequestBody(required = false) Map<String, Object> mapVal){
        if (mapVal == null) {
            mapVal = new HashMap<>();
        }
        return tmsshipFeign.addPleaseResult(mapVal);
    }

    @PostMapping("/editPleaseResult")
    public Map<String,Object> editPleaseResult(@RequestBody(required = false) Map<String, Object> mapVal){
        if (mapVal == null) {
            mapVal = new HashMap<>();
        }
        return tmsshipFeign.editPleaseResult(mapVal);
    }

    @PostMapping("/getAllPleaseResult")
    public Map<String,Object> getAllPleaseResult(@RequestBody(required = false) Map<String, Object> mapVal,
                                                 @RequestParam Integer pageNum,
                                                 @RequestParam Integer pageSize,
                                                 @RequestParam Integer apiId,
                                                  String con,
                                                  String startTime,
                                                  String endTime){
        if (mapVal == null) {
            mapVal = new HashMap<>();
        }
        return tmsshipFeign.getAllPleaseResult(mapVal,pageNum,pageSize,apiId,con,startTime,endTime);
    }

    @PostMapping("/getPleaseResult/{resultId}")
    public Map<String,Object> getPleaseResult(@PathVariable("resultId") BigDecimal resultId){
        return tmsshipFeign.getPleaseResult(resultId);
    }

    @PostMapping("/getRealNumber")
    public Map<String,Object> getRealNumber(@RequestBody(required = false) Map<String, Object> map){
        return tmsshipFeign.getRealNumber(map);
    }

    @PostMapping("/getWagonWork")
    public Map<String,Object> getWagonWork(@RequestBody(required = false) Map<String, Object> map){
        return tmsshipFeign.getWagonWork(map);
    }

    @PostMapping("/queryNumber")
    public Map<String,Object> queryNumber(@RequestParam String orderNumber){
        return tmsTruckFeign.queryNumber(orderNumber);
    }

    @PostMapping("/changeNumber")
    public Map<String,Object> changeNumber(@RequestParam String orderNumber){
        return tmsTruckFeign.changeNumber(orderNumber);
    }

    @ApiOperation("根据车序号id查询主干数据")
    @PostMapping("/getSteelReportDetailsBySmId")
    public Map<String,Object> getSteelReportDetailsBySmId(@RequestParam BigDecimal saleOrderMaterialId){
        return tmsTruckFeign.getSteelReportDetailsBySmId(saleOrderMaterialId);
    }




}