package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-BMSSHIP-API-DEV", url = "${openfeign.BmsshipFeign.url}")
public interface BmsshipFeign {

    /**
     * 展示港口装卸费
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getPortHandlingFeeList")
    RESTfulResult getPortHandlingFeeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                         @RequestParam("pageNum") Integer pageNum,
                                         @RequestParam("pageSize") Integer pageSize,
                                         @RequestParam("apiId") Integer apiId,
                                         @RequestParam("con") String con);

    /**
     * 展示批次信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getBatch")
    RESTfulResult getBatch(@RequestBody(required = false) Map<String, Object> mapValue,
                           @RequestParam("pageNum") Integer pageNum,
                           @RequestParam("pageSize") Integer pageSize,
                           @RequestParam("apiId") Integer apiId,
                           @RequestParam("con") String con);

    /**
     * 生成港口装卸费
     *
     * @param portHandlingFee
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/addPortHandlingFee")
    RESTfulResult addPortHandlingFee(@RequestBody Map<String, Object> portHandlingFee) throws Exception;

    /**
     * 修改港口装卸费信息
     *
     * @param portHandlingFee
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/updatePortHandlingFee")
    RESTfulResult updatePortHandlingFee(@RequestBody Map<String, Object> portHandlingFee);

    /**
     * 查询修改港口装卸费数据渲染表单
     *
     * @param feeId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getFeeToUpdate/{feeId}")
    RESTfulResult getFeeToUpdate(@PathVariable("feeId") BigDecimal feeId);

    /**
     * 逻辑删除港口装卸费
     *
     * @param feeId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/deletePortHandlingFee/{feeId}")
    RESTfulResult deletePortHandlingFee(@PathVariable("feeId") String feeId);

    /**
     * 展示水运详单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipdetailsorder/getDetailsOrderList")
    RESTfulResult getDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                      @RequestParam("pageNum") Integer pageNum,
                                      @RequestParam("pageSize") Integer pageSize,
                                      @RequestParam("apiId") Integer apiId,
                                      @RequestParam("con") String con);

    /**
     * 展示未生成账单的详单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipdetailsorder/getUncomplateDetailsOrderList")
    RESTfulResult getUncomplateDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                @RequestParam("pageNum") Integer pageNum,
                                                @RequestParam("pageSize") Integer pageSize,
                                                @RequestParam("apiId") Integer apiId,
                                                @RequestParam("con") String con);

    /**
     * 生成水运计费详单
     *
     * @param resultId
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipdetailsorder/addDetailsOrder/{resultId}")
    RESTfulResult addDetailsOrder(@PathVariable("resultId") BigDecimal resultId) throws Exception;


    /**
     * 展示水运费和水分质检费账单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/getStatementList")
    RESTfulResult getStatementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam("pageNum") Integer pageNum,
                                   @RequestParam("pageSize") Integer pageSize,
                                   @RequestParam("apiId") Integer apiId,
                                   @RequestParam("con") String con);

    /**
     * 展示途损费账单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/getLossStatementList")
    RESTfulResult getLossStatementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam("pageNum") Integer pageNum,
                                       @RequestParam("pageSize") Integer pageSize,
                                       @RequestParam("apiId") Integer apiId,
                                       @RequestParam("con") String con);

    /**
     * 展示水分质检实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/getWaterResult")
    RESTfulResult getWaterResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                 @RequestParam("pageNum") Integer pageNum,
                                 @RequestParam("pageSize") Integer pageSize,
                                 @RequestParam("apiId") Integer apiId);

    /**
     * 生成水运费账单
     *
     * @param mapList
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/addStatement")
    RESTfulResult addStatement(@RequestBody List<Map<String, Object>> mapList) throws Exception;

    /**
     * 生成水分质检账单
     *
     * @param mapList
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/addWaterStatement")
    RESTfulResult addWaterStatement(@RequestBody List<Map<String, Object>> mapList) throws Exception;

    /**
     * 生成途损账单
     *
     * @param map
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/addLossStatement")
    RESTfulResult addLossStatement(@RequestBody Map<String, Object> map) throws Exception;

    /**
     * 展示账单下的详单
     *
     * @param batchId
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/getStatementDetailsOrderList")
    RESTfulResult getStatementDetailsOrderList(@RequestParam BigDecimal batchId,
                                               @RequestBody(required = false) Map<String, Object> mapValue,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("statementId") BigDecimal statementId,
                                               @RequestParam("con") String con);

    /**
     * 展示详单下的船运实绩
     *
     * @param batchId
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/getShipResult")
    RESTfulResult getShipResult(@RequestParam BigDecimal batchId,
                                @RequestBody(required = false) Map<String, Object> mapValue,
                                @RequestParam("pageNum") Integer pageNum,
                                @RequestParam("pageSize") Integer pageSize,
                                @RequestParam("apiId") Integer apiId);

    /**
     * 查询水运费计算公式
     *
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipformulas/getShipFeesFormula")
    RESTfulResult getShipFeesFormula();

    /**
     * 查询途损费计算公式
     *
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipformulas/getLossFeesFormula")
    RESTfulResult getLossFeesFormula();

    /**
     * 查询水分质检计算公式
     *
     * @return
     */
    @PostMapping(value = "/api/v1/bmsship/bmsshipformulas/getWaterFeesFormula")
    RESTfulResult getWaterFeesFormula();

     //新增二程船装卸费用
    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/addPortHandlingFeeSecond")
    Map<String, Object> addPortHandlingFeeSecond(@RequestBody(required = true) Map<String, Object> map);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/uploadBmsshipOrder", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    Map<String, Object> uploadBmsshipOrder(@RequestPart("file") MultipartFile multipartFile);

    //下载水运单图片
    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/downloadBmsshipOrder")
    Map<String, Object> downloadBmsshipOrder(@RequestParam("resultId") Integer resultId);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/selectPortFeeSecondList")
    Map<String, Object> selectPortFeeSecondList(@RequestBody(required = false)Map<String, Object> mapVal,
                                                @RequestParam("pageNum")Integer pageNum,
                                                @RequestParam("pageSize")Integer pageSize,
                                                @RequestParam("apiId") Integer apiId,
                                                @RequestParam("startTime") String startTime,
                                                @RequestParam("feeType")Integer feeType,
                                                @RequestParam("endTime") String endTime,
                                                @RequestParam("con") String con);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getBmsshipFee/{id}")
    Map<String, Object> getBmsshipFee(@PathVariable("id") Integer id);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/deletePortHandlingFeeSecond/{feeId}")
    Map<String,Object> deletePortHandlingFeeSecond(@PathVariable("feeId")BigDecimal feeId);


    @PostMapping(value = "/api/v1/bmsship/bmsshipstatement/addwaterStatement")
    Map<String, Object> addwaterStatement(@RequestBody(required = false) Map<String, Object> map);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getTrainDetailsByBatch/{batchId}")
    Map<String,Object> getTrainDetailsByBatch(@PathVariable("batchId")BigDecimal batchId);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getTruckDetailsByBatch/{batchId}")
    Map<String,Object> getTruckDetailsByBatch(@PathVariable("batchId")BigDecimal batchId);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/findBatchHavingLoad")
    Map<String,Object> findBatchHavingLoad(String con);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/findLoadByBatch")
    Map<String, Object> findLoadByBatch(@RequestBody(required = false)Map<String, Object> mapVal,
                                                @RequestParam("pageNum")Integer pageNum,
                                                @RequestParam("pageSize")Integer pageSize,
                                                @RequestParam("apiId") Integer apiId,
                                                @RequestParam("batchId") BigDecimal batchId);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getShipFeeStatement")
    Map<String, Object> getShipFeeStatement(@RequestBody(required = false) Map<String, Object> map);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getShipFeeStatemented")
    Map<String, Object> getShipFeeStatemented(@RequestBody(required = false) Map<String, Object> map);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/addShipFeeStatement")
    Map<String, Object> addShipFeeStatement(@RequestBody(required = false) Map<String, Object> map);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/editShipFeeStatement")
    Map<String, Object> editShipFeeStatement(@RequestBody(required = false) Map<String, Object> map);

    @PostMapping(value = "/api/v1/bmsship/bmsporthandlingfee/getWetDryDetails")
    Map<String, Object> getWetDryDetails(@RequestBody(required = false) Map<String, Object> map);
}