package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Description:BmsshipFeign
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-BMSTRAIN-API-DEV", url = "${openfeign.BmstrainFeign.url}")
public interface BmstrainFeign {

    /**
     * 展示火运详单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstraindetailsorders/getTrainDetailsOrderList")
    RESTfulResult getTrainDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           @RequestParam("pageNum") Integer pageNum,
                                           @RequestParam("pageSize") Integer pageSize,
                                           @RequestParam("apiId") Integer apiId,
                                           @RequestParam("con") String con);

    /**
     * 展示未转账单的火运详单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstraindetailsorders/getUncomplateTrainDetailsList")
    RESTfulResult getUncomplateTrainDetailsList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                @RequestParam("pageNum") Integer pageNum,
                                                @RequestParam("pageSize") Integer pageSize,
                                                @RequestParam("apiId") Integer apiId,
                                                @RequestParam("con") String con);

    /**
     * 展示火运实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstraindetailsorders/getTrainResultList")
    RESTfulResult getTrainResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam("pageNum") Integer pageNum,
                                     @RequestParam("pageSize") Integer pageSize,
                                     @RequestParam("apiId") Integer apiId);

    /**
     * 生成火运详单
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstraindetailsorders/addTrainDetails")
    RESTfulResult addTrainDetails(@RequestBody Map<String, Object> map);

    /**
     * 展示火运账单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainstatement/getTrainStatementList")
    RESTfulResult getTrainStatementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam("pageNum") Integer pageNum,
                                        @RequestParam("pageSize") Integer pageSize,
                                        @RequestParam("apiId") Integer apiId,
                                        @RequestParam("con") String con);

    /**
     * 展示火运实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainstatement/getStatementTrainResultList")
    RESTfulResult getStatementTrainResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              @RequestParam("pageNum") Integer pageNum,
                                              @RequestParam("pageSize") Integer pageSize,
                                              @RequestParam("apiId") Integer apiId,
                                              @RequestParam("detailsId") Integer detailsId);

    /**
     * 展示账单下的详单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainstatement/getComplateTrainDetailsList")
    RESTfulResult getComplateTrainDetailsList(@RequestParam("batchId") BigDecimal batchId,
                                              @RequestBody(required = false) Map<String, Object> mapValue,
                                              @RequestParam("pageNum") Integer pageNum,
                                              @RequestParam("pageSize") Integer pageSize,
                                              @RequestParam("apiId") Integer apiId,
                                              @RequestParam("statementId") BigDecimal statementId,
                                              @RequestParam("con") String con);

    /**
     * 生成火运费账单
     *
     * @param mapList
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainstatement/addTrainStatement")
    RESTfulResult addTrainStatement(@RequestBody List<Map<String, Object>> mapList);
  
  /**
     * 展示销售火运结算列表
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainsettlement/getSettlementList")
    RESTfulResult getSettlementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam("pageNum") Integer pageNum,
                                    @RequestParam("pageSize") Integer pageSize,
                                    @RequestParam("apiId") Integer apiId,
                                    @RequestParam("con") String con);

    /**
     * 新增火运结算
     * @param bmstrainSettlement
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainsettlement/addTrainSettlement")
    Map<String,Object> addTrainSettlement(@RequestBody Map<String, Object> bmstrainSettlement);

    /**
     * 修改火运结算
     * @param bmstrainSettlement
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainsettlement/updateTrainSettlement")
    Map<String,Object> updateTrainSettlement(@RequestBody Map<String, Object> bmstrainSettlement);

    /**
     * 逻辑删除火运结算
     * @param settlementId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainsettlement/deleteTrainSettlement/{settlementId}")
    Map<String,Object> deleteTrainSettlement(@PathVariable("settlementId") BigDecimal settlementId);

    /**
     * 得到修改渲染
     * @param settlementId
     * @return
     */
    @PostMapping(value = "/api/v1/bmstrain/bmstrainsettlement/selectTrainSettlement/{settlementId}")
    Map<String,Object> selectTrainSettlement(@PathVariable("settlementId") BigDecimal settlementId);

}